*******************************************************************************

*** LABOR MARKET CONCENTRATION IN GERMANY

*** (C) MICHAEL OBERFICHTNER & MARTIN POPP

*******************************************************************************


*** 0. MASTER FILE ***


*** 0.1 PREAMBLE ***


*clear memory 

clear all


*activate rmsg command

set rmsg on


*deactivate more function

set more off, permanently


*specify Stata version

version 16


*faster calculations (but more memory needed) for mata 

mata: mata set matafavor speed, perm


*set seed number
         
set seed 1265674183
		 
*increase maximum size for matrices

set matsize 10000


*increase maximum size for matrices

set maxvar 10000


*save current date in macro

global cdate : di %tdCCYY-NN-DD date(c(current_date), "DMY")
display %tdCCYY-NN-DD "$cdate"


*save paths for working directory as global


global main = "\\iab.baintern.de\DFS\017\Ablagen\D01700-Projekte\4803-HHI-GER\Data"
global data = "$main\data" 
global doc = "$main\doc"
global fig = "$main\fig"
global file ="$main\file"
global log = "$main\log"
global orig = "$main\orig"
global prog ="$main\prog"



*specify working directory

cd "$main"


*add path for ado directories

sysdir set PERSONAL "$prog\ado\personal" // self-written ado files 
sysdir set PLUS "$prog\ado\stbplus" // installed ado files (via "ssc install ...")
sysdir set OLDPLACE "$prog\ado\oldplace" // no longer needed

*tell mata where ado directories are

mata: mata mlib index

sysdir


*install ado files (in PLUS directory)

*ssc install mergepoly 
*ssc install shp2dta 
*ssc install spmap 
*ssc install binscatter
*ssc install reghdfe
*ssc install ftools

*ado
*adoupdate




*** 0.1 LABELS ***

log using $log\0_1_Labels.log, replace

do $prog\0_1_Labels.do 

log close




exit



*** 1. PREPARATION OF DATA ***


log using "$log\1_Preparation_of_Data_$cdate.log", replace 

do "$prog\1_Preparation_of_HHI.do"

log close 



*** 2. SELF-CONTAINMENT OF LABOR MARKETS ***


log using "$log\2_Self-Containment_$cdate.log", replace 

do "$prog\2_Self-Containment.do"

log close 





*** 3. LABOR MARKET CONCENTRATION ***


log using "$log\3_Labor_Market_Concentration_$cdate.log", replace 

do "$prog\3_Labor_Market_Concentration.do"

log close 




*** 4. REGRESSIONS ***


log using "$log\4_Regressions_$cdate.log", replace 

do "$prog\4_Regressions.do"

log close 




*** 5. MULTI-FIRM COMPANIES ***


log using "$log\5_Multi-Firm_Companies_$cdate.log", replace 

do "$prog\5_Multi-Firm_Companies.do"

log close 


