

*** 1. PREPARATION OF DATA ***


*** 1.1 MAP MATERIAL ***

clear

*source of map data: https://gdz.bkg.bund.de/index.php/default/digitale-geodaten/verwaltungsgebiete/verwaltungsgebiete-1-250-000-stand-01-01-vg250-01-01.html
*name of dataset: Verwaltungsgebiete 1:250 000 - Stand 01.01.2023
*note: 1 Jan 2024 refers to administrative delineation valid on 31 Dec 2023

*see the following link: https://www.stata.com/support/faqs/graphics/spmap-and-maps/

cd "$orig\Map\vg250_01-01.tm32.shape.ebenen\vg250_ebenen_0101"


*create dta files (can be read by Stata) from db and shp files (cannot be read by Stata)
shp2dta using VG250_KRS, database(db) coordinates(coord) genid(mapid) replace

use "db.dta", clear
save "$data\db.dta", replace

use "coord.dta", clear
save "$data\coord.dta", replace



cd "$main"
use "$data\db.dta", clear

count if ARS!=AGS

duplicates report ARS // (371-0) + (50-25) + (12-8) = 371 + 25 + 4 = 400 = 106 independent towns + 294 districts


*note: due to islands or enclaves, some districts or independent towns have more than one observation in map file


sort ARS 
destring ARS, replace // RS is saved as a string (str5), but for merging later on we need integer format
rename ARS nuts07_3   

save "$data\db.dta", replace



*create map for Germany (with "mergepoly" command)   
use "$data\db.dta", clear   
mergepoly mapid using "$data\coord.dta", coor("$data\coord_empty.dta") replace // no by(...) since Germany as ONE region is wanted
spmap using "$data\coord_empty.dta", id(mapid) osize(vthin)
graph export "$fig\Germany.png", replace width(8000)
graph export "$fig\Germany.pdf", replace
*graph export "$fig\Germany.emf", replace



*create map for Germany with administrative delineation (without "mergepoly" command)
use "$data\db.dta", clear


	preserve // calculate centroids of regions
	
		use "$data\coord.dta", clear
		bys _ID: gen float TEMPa=(_X*_Y[_n+1])-(_X[_n+1]*_Y) if _n>1 & _n<_N
		bys _ID: gen float _AREA=sum(TEMPa)
		bys _ID: replace _AREA=_AREA[_N]/2
		bys _ID: gen float TEMPx=(_X+_X[_n+1])*(_X*_Y[_n+1]-_X[_n+1]*_Y) if _n>1 & _n<_N
		bys _ID: gen float _CX=sum(TEMPx)
		bys _ID: replace _CX=_CX[_N]/(6*_AREA)
		bys _ID: gen float TEMPy=(_Y+_Y[_n+1])*(_X*_Y[_n+1]-_X[_n+1]*_Y) if _n>1 & _n<_N
		bys _ID: gen float _CY=sum(TEMPy)
		bys _ID: replace _CY=_CY[_N]/(6*_AREA)
		collapse _CX _CY, by(_ID)
		
		rename _ID mapid
		save "$data\coord_centroids.dta", replace
	
		use "$data\db.dta", clear

		
		merge 1:1 mapid using "$data\coord_centroids.dta"
		drop _merge
				
		gen label = ""
		replace label = "B" if mapid==325 // Berlin, kreisfreie Stadt		
		replace label = "H" if mapid==16  // Hamburg, kreisfreie Stadt	
		replace label = "M" if mapid==224 // München, kreisfreie Stadt	
		replace label = "C" if mapid==80  // Köln, kreisfreie Stadt	

		
		replace _CX = 359000.0 if mapid==80 // 357636.1
		replace _CX = 476500.0 if mapid==118 // 474555.8


		keep nuts07_3 mapid _CX _CY label
		
		save "$data\db_label.dta", replace
					
	restore

gen shade = (inlist(mapid, 325,16,224,80))
tab shade, m

*spmap using "$data\coord.dta", id(mapid) osize(vthin) 
spmap shade using "$data\coord.dta", id(mapid) osize(vthin) legenda(off) label(data("$data\db_label.dta") xcoord(_CX) ycoord(_CY) label(label) size(vsmall) color(white))	
graph export "$fig\Administrative LM Delineation.png", replace width(8000)
graph export "$fig\Administrative LM Delineation.pdf", replace
*graph export "$fig\Administrative LM Delineation.emf", replace


				
				
				
				
				
				
				
				
				
				
				

/*		
*========================= STATA SELF-SERVICE: BEGIN ==========================*

*disable "save" commands, except last one
*capture code for stata self-service by log file

log using "$log\\${AMSNr}_STATA_Self-Service_`c(current_date)'.log", name(stataselfservice) replace

*==============================================================================*



*** 1.2 PREPARATION OF BEH DATA: LABOR MARKET CONCENTRATION ***


*** 1.2.1 DEFINE BEH EXTRACT FOR DIM DEPARTMENT ***


*not necessary 

*reason: STATA self-service from DIM is used


*** 1.2.2 LOAD DATASET ***



*description of underlying BeH dataset:
*- 100% universe of observations from BeH v10.08.00-202312  ...
*- ... between 1 Jan 2010 and 31 Dec 2023
*- ... without episode splitting
*- ... with additional variables: imputed education (Thomsen et al., 2018), imputed part-time (Ludsteck/Thomsen, 2016), imputed industries, imputed wages (Drechsler et al., 2023)


*describe using "$orig\BeH\... .dta" 


*load standard BeH variables

use $beh\\$beh_bez, clear 



*add additional BeH variables (upon request from DIM department)


merge 1:1 ieb_fall_id using "$beh\\$imp_az"
drop if _merge==2
drop _merge		

merge 1:1 ieb_fall_id using "$beh\\$ip1"	
drop if _merge==2		
drop _merge

merge 1:1 ieb_fall_id using "$beh\\$wz08_kons"	
drop if _merge==2
drop _merge

merge 1:1 ieb_fall_id using "$beh\$arbstd"
drop if _merge==2		
drop _merge

merge 1:1 ieb_fall_id using "$beh\$tagentgelt1" // Datei "tag_entgelt_imputiert"  
drop if _merge==2		
drop _merge

merge 1:1 ieb_fall_id using "$beh\$tagentgelt2" // Datei "redundant_oder_fehlend" 
drop if _merge==2		
drop _merge

merge 1:1 ieb_fall_id using "$beh\$tagentgelt3" // Datei "bonus_integriert" 
drop if _merge==2		
drop _merge









			/*

			*** NOTE: only test data from now on (2% BeH sample)***

			
			*set number of extraction from DIM
			
			global AMSNr = "016213"
			display `"${AMSNr}"'
			
			*load standard BeH variables

			use "N:\Ablagen\D01700-Projekte\4803-HHI-GER\Data\orig\BeH\Test_Data\BeH_v_10_08_00_test\beh_2pct_v_10_08_00_202212\beh_stp2pct_v_10_08_00.dta", clear 
			rename geb_dat geb_mon

			*add additional BeH variables (upon request from DIM department)


			*load imputed education variable 

			merge 1:1 ieb_fall_id using "N:\Ablagen\D01700-Projekte\4803-HHI-GER\Data\orig\BeH\Test_Data\BeH_v_10_08_00_test\beh_2pct_v_10_08_00_202212\imp_ip1_beh2pct_v_10_08_00.dta"
			drop if _merge==2
			drop _merge

			*load industry classification variable 

			merge 1:1 ieb_fall_id using "N:\Ablagen\D01700-Projekte\4803-HHI-GER\Data\orig\BeH\Test_Data\BeH_v_10_08_00_test\beh_2pct_v_10_08_00_202212\wz08_kons_beh2pct_v_10_08_00.dta"
			drop if _merge==2
			drop _merge

			*load imputed part-time variable (only observations with effective imputation)

			merge 1:1 ieb_fall_id using "N:\Ablagen\D01700-Projekte\4803-HHI-GER\Data\orig\BeH\Test_Data\BeH_v_10_08_00_test\beh_2pct_v_10_08_00_202212\imp_az_beh2pct_v_10_08_00.dta"

			drop if _merge==2
			drop _merge


			*load hours variable (fake data, as not included in test data)
			
			gen beh_arbstd = uniform() * 40 * 52 * [ (beh_end_dat - beh_beg_dat + 1 ) / 365 ]


			*load imputed wage varables (fake data, as not included in test data)
			
			gen tegi = 1.3 * beh_tag_entg
			gen aeeg = 0.1/1.3
			
			gen grund_teilzeit = 0
			gen grund_geringfuegig = 0
			gen grund_alter = 0
			gen grund_ost_start = 0
			gen grund_nulls = 0
			gen grund_duplikat = 0
			gen grund_einmalzahlung = 0 
			gen ist_imputiert = 1

			gen tag_entg_zensiert  = 1.1 * beh_tag_entg
			gen ant_eeg = 0.1


			*/

*create year variable from spell information

gen year = year(beh_beg_dat)

tab year, m

*note:
*1975-2020: 36-month data material (100%)
*2021-2022: 18-month data material (99%)
*2023: 6-month data material (97%) 

keep if year>=2011 & year<=2023 


label data ""


save $data\\${AMSNr}_BeH_1123_V0.dta, replace
*use $data\\${AMSNr}_BeH_1123_V0.dta, clear





*** 1.2.3 CLEAN DATASET ***


*label ID variables


label variable prs_id "Person"
label variable year "Year"
label variable betnr "Establishment"
label variable ieb_fall_id "Observation ID"





*keep only necessary variables and observations



keep prs_id year betnr ieb_fall_id /// krk_betnr vrs_id
	 beh_beg_dat beh_end_dat /// beh_erst_dat beh_dauer
	 beh_tag_entg /// beh_entgelt whrng_knz
	 tag_entg_mit_bonus ant_eeg ///
	 tegi aeeg ist_imputiert grund_teilzeit grund_geringfuegig grund_alter grund_ost_start grund_nulls grund_duplikat grund_einmalzahlung ///
	 /// beitr_av beitr_kv beitr_pv beitr_rv beh_vs_tr 
	 /// beh_arbstd
	 beh_pers_gr berufstellg berufstellg_imp_num beh_abg /// bzp_id beh_status_kz
	 geb_dat_ano sex_id beh_staat_num ///
	 /// beh_an_ueberlass beh_befristung gleitzone
	 beh_ausbildung beh_ausbildung_imp /// beh_schul_abschl beh_ausb_abschl
	 wz08_kons_num /// wz73_num wz93_num wz03_num wz08_num
	 beh_beruf_kldb10_num /// beh_beruf_num 
	 e_krs_schl_ao_akt_num e_gem_schl_ao_akt_num /// e_gst_schl_ao_akt_num e_aa_schl_ao_akt_num    				
	 /// b_krs_schl_ao_akt_num b_gem_schl_ao_akt_num b_gst_schl_ao_akt_num b_aa_schl_ao_akt_num     	
	 /// e_krs_schl_wo_akt_num e_gem_schl_wo_akt_num e_gst_schl_wo_akt_num e_aa_schl_wo_akt_num	
	 /// b_krs_schl_wo_akt_num b_gem_schl_wo_akt_num b_gst_schl_wo_akt_num b_aa_schl_wo_akt_num		
	 ow_knz
	    

compress grund_* 	 

	 
	 
*sort and order data

sort prs_id year betnr ieb_fall_id

order prs_id year betnr ieb_fall_id /// krk_betnr vrs_id
	  beh_beg_dat beh_end_dat /// beh_erst_dat beh_dauer
	  beh_tag_entg /// beh_entgelt whrng_knz 
	  tag_entg_mit_bonus ant_eeg ///
	  tegi aeeg ist_imputiert grund_teilzeit grund_geringfuegig grund_alter grund_ost_start grund_nulls grund_duplikat grund_einmalzahlung /// 
	  /// beitr_av beitr_kv beitr_pv beitr_rv beh_vs_tr 
	  /// beh_arbstd
	  beh_pers_gr berufstellg berufstellg_imp_num beh_abg /// bzp_id beh_status_kz
	  geb_dat_ano sex_id beh_staat_num ///
	  /// beh_an_ueberlass beh_befristung gleitzone
	  beh_ausbildung beh_ausbildung_imp /// beh_schul_abschl beh_ausb_abschl
	  wz08_kons_num /// wz73_num wz93_num wz03_num wz08_num
	  beh_beruf_kldb10_num /// beh_beruf_num 
	  e_krs_schl_ao_akt_num e_gem_schl_ao_akt_num /// e_gst_schl_ao_akt_num e_aa_schl_ao_akt_num    				
	  /// b_krs_schl_ao_akt_num b_gem_schl_ao_akt_num b_gst_schl_ao_akt_num b_aa_schl_ao_akt_num     	
	  /// e_krs_schl_wo_akt_num e_gem_schl_wo_akt_num e_gst_schl_wo_akt_num e_aa_schl_wo_akt_num	
	  /// b_krs_schl_wo_akt_num b_gem_schl_wo_akt_num b_gst_schl_wo_akt_num b_aa_schl_wo_akt_num		
	  ow_knz
	 
	 
format %17.0g ieb_fall_id


*drop if establishment is unknown

drop if betnr==.


compress


save $data\\${AMSNr}_BeH_1123_V1.dta, replace
use $data\\${AMSNr}_BeH_1123_V1.dta, clear


drop beh_ausbildung ant_eeg aeeg grund_*

save $data\\${AMSNr}_BeH_1123_V2.dta, replace


*==============================================================================*


*delete data sets from intermediate steps

cap erase $data\\${AMSNr}_BeH_1123_V0.dta
cap erase $data\\${AMSNr}_BeH_1123_V1.dta

*evaluate size of dataset 

*note: maximum sample from DIM = 10% of entire IEB ~ 50 GB

checksum $data\\${AMSNr}_BeH_1123_V2.dta


display r(filelen)

*display round( 50 * r(filelen) / 1000000000, 0.01) " GB" // test data

display round( 1 * r(filelen) / 1000000000, 0.01) " GB" // final data


log close stataselfservice


*========================== STATA SELF-SERVICE: END ===========================*
*/




						
use "$orig\BeH\016213_BeH_1123_V2.dta", clear					
cap drop beh_entgelt


*** 1.2.4 ANALOGOUS DATA ADJUSTMENTS TO ESTABLISHMENT HISTORY PANEL (EXCEPT: WAGE IMPUTATION, REFERENCE DATE, AND DELETION OF MULTIPLE PERSON-ESTABLISHMENT RELATIONSHIPS WITHIN ONE YEAR ) ***



*** (A) IMPUTATION OF EDUCATION VARIABLE ***


*source: Ganzer et al. (2023, p.17)

*note: must be done before episode splitting is undone and irrelevant employment spells are deleted

*imputation of education variable by means of Thomsen et al. (2018)
*has already been implemented in variable "beh_ausbildung_imp"


*tab beh_ausbildung, m // there are missing values
*count if ( beh_ausbildung==-9 | beh_ausbildung==-5 | beh_ausbildung== 7 | beh_ausbildung==9 ) // some observations are missing

tab beh_ausbildung_imp, m // imputation from Thomsen et al. (2018)
count if beh_ausbildung_imp==-7 // fewer observations are only missing anymore

*drop beh_ausbildung



*** (B) UNDO EPISODE SPLITTING ***

*source: Antoni et al. (2016, p.27)

*irrelevant as data do not feature episode splitting




*** (C) CONSIDERATION OF RELEVANT EMPLOYMENT SPELLS ***

*only consider the following employment relationships:
*101,102,103,105,106,109,112,113,114,118,119,120,121,122,140,141,142,143,144,149,201,202,203,205,209,999,YYY
*source: Ganzer et al. (2020, p.13 & 111f)

tab beh_pers_gr, m

keep if beh_pers_gr == 101 |  beh_pers_gr == 102 | beh_pers_gr == 103 | beh_pers_gr == 105 | /// 
        beh_pers_gr == 106 |  beh_pers_gr == 109 | beh_pers_gr == 112 | beh_pers_gr == 113 | /// 
        beh_pers_gr == 114 |  beh_pers_gr == 118 | beh_pers_gr == 119 | beh_pers_gr == 120 | /// 
        beh_pers_gr == 121 |  beh_pers_gr == 122 | beh_pers_gr == 140 | beh_pers_gr == 141 | ///
		beh_pers_gr == 142 |  beh_pers_gr == 143 | beh_pers_gr == 144 | beh_pers_gr == 149 | ///
		beh_pers_gr == 201 |  beh_pers_gr == 203 | beh_pers_gr == 205 | beh_pers_gr == 209 | /// 
		beh_pers_gr == 299 |  beh_pers_gr == 999 | beh_pers_gr == -8  // drop all notifications with irrelevant employment status

		
		


gen contract = .
replace contract = 1 if (beh_pers_gr==101 | beh_pers_gr==113 | beh_pers_gr==114 | beh_pers_gr==140 | beh_pers_gr==143) // regular employment
replace contract = 2 if (beh_pers_gr==109 | beh_pers_gr==209) // marginal employment
replace contract = 3 if (beh_pers_gr==102 | beh_pers_gr==121 | beh_pers_gr==122 | beh_pers_gr==141 | beh_pers_gr==144) // apprenticeship
replace contract = 4 if (beh_pers_gr==103 | beh_pers_gr==142) // partial retirement
replace contract = 5 if (beh_pers_gr==105 | beh_pers_gr==106 | beh_pers_gr==112 | beh_pers_gr==118 | beh_pers_gr==119 | beh_pers_gr==120 | beh_pers_gr==149 | beh_pers_gr==201 | beh_pers_gr==203 | beh_pers_gr==205 | beh_pers_gr==999 | beh_pers_gr==-8) // other employment

label define contract 1 "1 Regular Employment" 2 "2 Marginal Employment" 3 "3 Apprenticeship" 4 "4 Partial Retirement" 5 "5 Other Employment" 
label values contract contract

tab contract, m		
tab year contract, m nofreq row

drop beh_pers_gr




*** (D) IMPUTATION FOR PART-TIME VARIABLE ***


*source: Ganzer et al. (2023, p.18)

*imputation of part-time variable by means of Thomsen/Ludsteck (2016)
*has already been implemented in variable "berufstellg_imp_num"



tab berufstellg, m	
count if ( berufstellg==-9 | berufstellg==-7 | berufstellg==-5 | berufstellg==5 | berufstellg==6 ) // some observations are missing

tab berufstellg_imp_num, m // imputation from Ludsteck/Thomsen (2016) --> this variable includes only imputed values

replace berufstellg=20 if berufstellg_imp_num==20
replace berufstellg=21 if berufstellg_imp_num==21

drop berufstellg_imp_num
rename berufstellg berufstellg_imp

tab berufstellg_imp, m
count if ( berufstellg_imp==-9 | berufstellg_imp==-5 | berufstellg_imp==-5 | berufstellg_imp==5 | berufstellg_imp==6) // 4,857,744 observations are only missing anymore


gen parttime_imp = .
replace parttime_imp = 0 if ( berufstellg_imp==0  | berufstellg_imp==1  | berufstellg_imp==2  | berufstellg_imp==3  | berufstellg_imp==4 |  berufstellg_imp==7 | berufstellg_imp==20 )
replace parttime_imp = 1 if ( berufstellg_imp==8  | berufstellg_imp==9  | berufstellg_imp==21 )
replace parttime_imp = . if ( berufstellg_imp==-9 | berufstellg_imp==-8 | berufstellg_imp==-7 | berufstellg_imp==-6 | berufstellg_imp==-5 | berufstellg_imp==5 | berufstellg_imp==6 )



label variable parttime_imp "Part-Time Employment (0=No, 1=Yes)"

tab parttime_imp, m		
tab year parttime_imp, m nofreq row

*drop berufstellg_imp




*** (E) DELETION OF OBSERVATIONS WITH ZERO WAGES ***


*delete observations with zero wages
*source: Ganzer et al. (2023, p.15)

count if beh_tag_entg==0 // ...
drop if beh_tag_entg==0


*additional adjustment (not in BHP):

count if beh_tag_entg==. // ...
drop if beh_tag_entg==.



*** (F) CONVERSION TO EURO ***


*note: variable "beh_tag_entg" is already expressed in Euro for all years
*source: Grießemer (2024, p. 36 & 79)
*no need for conversion

*note: variable "beh_entg" is expressed in DM for years before 1999
*source: Grießemer (2024, p. 36 & 70)
*no need for conversion since data extract begins in 2011 only




*** (G) ADDITION OF SPECIAL PAYMENTS AND EXCLUSION OF DUPLICATES WITH IDENTICAL BEGIN AND END DATE FOR THE SAME WORKER-FIRM PAIR ***


*add special payments (holiday pay, christmas bonus) to normal employment spells
*source: Ganzer et al. (2023, p.16), Drechsler et al. (2023, p. 15f & Footnote 17)


*remove duplicates with identical begin and end date for the same worker-firm pair
*source: Drechsler et al. (2023, p. 15f)



*taxonomy of "duplicates"
*type I: perfect duplicates, i.e., fully identical spells --> already cleaned by DIM in course of BeH preparation
*type II: worker-firm-year triples with very same begin and end date but differing values in other variables (e.g. wages) --> these are likely replacement notifications --> should not enter wage imputation simultaneously; standard practice in BHP: keep only most important spell in the same firm (in terms of duration, wage) --> elimination of type II/III duplicates
*type III: worker-firm-year triples with different begin and end dates --> may enter wage imputation simultaneously; standard practice in BHP: keep only most important spell in the same firm (in terms of duration, wage) --> elimination of type II/III duplicates
*type IV: worker-year couples at different firms --> sometimes: keep only main employment of worker in a year


*however, this paper: calculation of wage bill concentration in year concept is not compatible with keeping only most important spell for worker-firm-year triple


*variable "tag_entg_mit_bonus" already includes special payments and is set "." for type II duplicates

*step 1: identify type 2 duplicates, replace wage by average wage across type II duplicates, keep one observation and delete the others
*step 2: add sum of all special payments for the worker-firm-year triple to the remaining spells


gen tag_entg_mit_bonus_miss = ( tag_entg_mit_bonus==. )
tab year tag_entg_mit_bonus_miss, m


count if beh_abg==54

tab tag_entg_mit_bonus_miss, m
tab tag_entg_mit_bonus_miss if beh_abg!=54, m
*tab tag_entg_mit_bonus_miss if beh_abg!=54 & grund_duplikat==1, m


drop if tag_entg_mit_bonus==. // drop type II duplicates


count if beh_abg==54 // zero
drop if beh_abg==54 // irrelevant

rename tag_entg_mit_bonus wage_day 

label variable wage "Gross Daily Wage (w/ Special Payments)"


*hist ant_eeg
*drop if ant_eeg>... & !missing(ant_eeg)


*drop beh_tag_entg

**# Bookmark #1



/*

*** (H) EXTRACT REFERENCE DATE INFORMATION FROM SPELL DATA ***


*does not make sense here --> keep all spells for application of different hiring concepts later on



*** (I) DELETE MULTIPLE PERSON-ESTABLISHMENT RELATIONSHIPS WITHIN ONE YEAR ***

*does not make sense here --> keep all spells and delete multiple person-establishment relationship separately for each inflow concept



*/



*delete unneeded variables


keep prs_id year betnr ieb_fall_id /// 
	 beh_beg_dat beh_end_dat ///
	 wage tegi ist_imputiert /// aeeg
	 contract parttime_imp /// 
	 geb_dat_ano sex_id beh_staat_num /// 
	 beh_ausbildung_imp /// 
	 wz08_kons_num /// 
	 beh_beruf_kldb10_num /// beh_beruf_num 
	 e_krs_schl_ao_akt_num e_gem_schl_ao_akt_num ///
	 ow_knz
			


save "$data\BeH_1123_V3.dta", replace
use "$data\BeH_1123_V3.dta", clear





*** 1.2.5 PREPARATION OF BEH VARIABLES ***






*** (B) START DATE

rename beh_beg_dat start

*tab start, m	

label variable start "Start Date of Spell"

format start %tdDD_Mon_CCYY



*** (C) END DATE


rename beh_end_dat end

*tab end, m	

label variable end "End Date of Spell"

format end %tdDD_Mon_CCYY






			
*** (D) SPELL DURATION


gen duration = end - start + 1

tab duration, m

label variable duration "Spell Duration (in Days)"





*** (E) WORKING TIME INDICATOR

tab parttime_imp, m	

label variable parttime_imp "Part-Time Employment (0=No, 1=Yes)"

label define parttime 0 "0 No" 1 "1 Yes"
label values parttime parttime


*** (F) EMPLOYMENT TYPE


gen type = .
replace type = 1 if contract==1 & parttime_imp==0 // regular employment: full-time
replace type = 2 if contract==1 & parttime_imp==1 // regular employment: part-time
replace type = 3 if contract==2 // marginal employment
replace type = 4 if contract==3 // apprenticeship
replace type = 5 if contract==4 // partial retirement
replace type = 6 if contract==5 & parttime_imp==0 // other employment: full-time
replace type = 7 if contract==5 & parttime_imp==1 // other employment: part-time


label variable type "Type of Employment"

label define type 1 "1 Regular Employment: FT" 2 "2 Regular Employment: PT" 3 "3 Marginal Employment" 4 "4 Apprenticeship" 5 "5 Partial Retirement"  6 "6 Other Employment: FT"  7 "7 Other Employment: PT"
label values type type


tab type, m

tab type parttime_imp, m

drop contract			
			
		
		
		
		
		
		
*** (G) GENDER


tab sex_id, m  // there are no missing values
recode sex_id (1=0) (2=1)

rename sex_id female

label variable female "Female (0=No, 1=Yes)"

label define female 0 "0 No" 1 "1 Yes" 
label values female female

tab female, m



*** (H) AGE 

format geb_dat_ano %tdD_m_CY

gen date = mdy(6, 30, year) // 30 June of each year
gen age = round((date - geb_dat_ano)/365.25, 0.01)
drop date

label variable age "Age (in Years, as of 30 June)"

format %15.1f age

sum age

replace age = . if age < 15
replace age = . if age > 90


		
		
		
	

*** (I) EDUCATION


tab beh_ausbildung_imp // there are missing values

gen educ_imp = .
replace educ_imp = 0 if (beh_ausbildung_imp==-7) // unknown education
replace educ_imp = 1 if (beh_ausbildung_imp==0 | beh_ausbildung_imp==1 | beh_ausbildung_imp==3) // low education
replace educ_imp = 2 if (beh_ausbildung_imp==2 | beh_ausbildung_imp==4) // medium education
replace educ_imp = 3 if (beh_ausbildung_imp==5 | beh_ausbildung_imp==6) // high education

tab educ_imp, m

label variable educ_imp "Education"

label define educ 0 "0 Unknown Education" 1 "1 Low Education" 2 "2 Medium Education" 3 "3 High Education" 

label values educ_imp educ



*tab year educ_imp, m 
*tab year educ_imp, m row nofreq
*tab year educ_imp if regothft==1 & age>=15, m
*tab year educ_imp if regothft==1 & age>=15, m nofreq row





*** (J) NATIONALITY

tab beh_staat_num, m // there are missing values

gen foreign = .
replace foreign = 0 if beh_staat_num==0 // German nationality
replace foreign = 1 if ( beh_staat_num>0 & beh_staat_num<=997 ) // foreign nationality  
replace foreign = . if ( beh_staat_num==998 | beh_staat_num==999 ) // unknown nationality

label variable foreign "Foreign Nationality (0=No, 1=Yes)"

label define foreign 0 "0 No" 1 "1 Yes"  
label values foreign foreign

tab foreign, m

	
		
		
		
		
		


*** (K) INDUSTRY ***



*WZ08-5 industries (839 subclasses)

rename wz08_kons_num wz08_5_imp

*tab wz08_5_imp, m 
recode wz08_5_imp (-9=.) (-8=.) (-7=.) (-6=.) (-5=.)

gen wz08_5_imp_miss = (wz08_5_imp==.)
tab year wz08_5_imp_miss
drop wz08_5_imp_miss

quietly do "$prog\WZ08-5.do"
label values wz08_5_imp wz08_5
format %50.0f wz08_5_imp

tab wz08_5_imp, m


*WZ08-4 industries (615 classes)

gen wz08_4_imp = floor(wz08_5_imp/10)

quietly do "$prog\WZ08-4.do"
label values wz08_4_imp wz08_4
format %50.0f wz08_4_imp

tab wz08_4_imp, m



*WZ08-3 industries (272 groups)

gen wz08_3_imp = floor(wz08_4_imp/10) 

quietly do "$prog\WZ08-3.do"
label values wz08_3_imp wz08_3
format %50.0f wz08_3_imp

tab wz08_3, m



*WZ08-2 industries (88 divisions)

gen wz08_2_imp = floor(wz08_3_imp/10) 

quietly do "$prog\WZ08-2.do"
label values wz08_2_imp wz08_2
format %50.0f wz08_2_imp

tab wz08_2_imp, m


*WZ08-1C industries (38 small sections)

gen wz08_1c_imp = . 
replace wz08_1c_imp =  1 if wz08_2_imp>= 1 & wz08_2_imp<= 3 // A
replace wz08_1c_imp =  2 if wz08_2_imp>= 5 & wz08_2_imp<= 9 // B
replace wz08_1c_imp =  3 if wz08_2_imp>=10 & wz08_2_imp<=12 // CA
replace wz08_1c_imp =  4 if wz08_2_imp>=13 & wz08_2_imp<=15 // CB
replace wz08_1c_imp =  5 if wz08_2_imp>=16 & wz08_2_imp<=18 // CC
replace wz08_1c_imp =  6 if wz08_2_imp==19 // CD
replace wz08_1c_imp =  7 if wz08_2_imp==20 // CE
replace wz08_1c_imp =  8 if wz08_2_imp==21 // CF
replace wz08_1c_imp =  9 if wz08_2_imp>=22 & wz08_2_imp<=23 // CG
replace wz08_1c_imp = 10 if wz08_2_imp>=24 & wz08_2_imp<=25 // CH
replace wz08_1c_imp = 11 if wz08_2_imp==26 // CI
replace wz08_1c_imp = 12 if wz08_2_imp==27 // CJ
replace wz08_1c_imp = 13 if wz08_2_imp==28 // CK
replace wz08_1c_imp = 14 if wz08_2_imp>=29 & wz08_2_imp<=30 // CL
replace wz08_1c_imp = 15 if wz08_2_imp>=31 & wz08_2_imp<=33 // CM
replace wz08_1c_imp = 16 if wz08_2_imp==35  // D
replace wz08_1c_imp = 17 if wz08_2_imp>=36 & wz08_2_imp<=39 // E
replace wz08_1c_imp = 18 if wz08_2_imp>=41 & wz08_2_imp<=43 // F
replace wz08_1c_imp = 19 if wz08_2_imp>=45 & wz08_2_imp<=47 // G
replace wz08_1c_imp = 20 if wz08_2_imp>=49 & wz08_2_imp<=53 // H
replace wz08_1c_imp = 21 if wz08_2_imp>=55 & wz08_2_imp<=56 // I
replace wz08_1c_imp = 22 if wz08_2_imp>=58 & wz08_2_imp<=60 // JA
replace wz08_1c_imp = 23 if wz08_2_imp==61 // JB
replace wz08_1c_imp = 24 if wz08_2_imp>=62 & wz08_2_imp<=63 // JC
replace wz08_1c_imp = 25 if wz08_2_imp>=64 & wz08_2_imp<=66 // K
replace wz08_1c_imp = 26 if wz08_2_imp==68 // L
replace wz08_1c_imp = 27 if wz08_2_imp>=69 & wz08_2_imp<=71 // MA
replace wz08_1c_imp = 28 if wz08_2_imp==72 // MB
replace wz08_1c_imp = 29 if wz08_2_imp>=73 & wz08_2_imp<=75 // MC
replace wz08_1c_imp = 30 if wz08_2_imp>=77 & wz08_2_imp<=82 // N
replace wz08_1c_imp = 31 if wz08_2_imp==84 // O
replace wz08_1c_imp = 32 if wz08_2_imp==85 // P
replace wz08_1c_imp = 33 if wz08_2_imp==86 // QA
replace wz08_1c_imp = 34 if wz08_2_imp>=87 & wz08_2_imp<=88 // QB
replace wz08_1c_imp = 35 if wz08_2_imp>=90 & wz08_2_imp<=93 // R
replace wz08_1c_imp = 36 if wz08_2_imp>=94 & wz08_2_imp<=96 // S
replace wz08_1c_imp = 37 if wz08_2_imp>=97 & wz08_2_imp<=98 // T
replace wz08_1c_imp = 38 if wz08_2_imp==99 // U

quietly do "$prog\WZ08-1C.do"
label values wz08_1c_imp wz08_1c
format %50.0f wz08_1c_imp

tab wz08_1c_imp, m


*WZ08-1B industries (21 sections)

gen wz08_1b_imp = . 
replace wz08_1b_imp =  1 if wz08_2_imp>= 1 & wz08_2_imp<= 3 // A
replace wz08_1b_imp =  2 if wz08_2_imp>= 5 & wz08_2_imp<= 9 // B
replace wz08_1b_imp =  3 if wz08_2_imp>=10 & wz08_2_imp<=33 // C
replace wz08_1b_imp =  4 if wz08_2_imp==35 // D
replace wz08_1b_imp =  5 if wz08_2_imp>=36 & wz08_2_imp<=39 // E
replace wz08_1b_imp =  6 if wz08_2_imp>=41 & wz08_2_imp<=43 // F
replace wz08_1b_imp =  7 if wz08_2_imp>=45 & wz08_2_imp<=47 // G
replace wz08_1b_imp =  8 if wz08_2_imp>=49 & wz08_2_imp<=53 // H
replace wz08_1b_imp =  9 if wz08_2_imp>=55 & wz08_2_imp<=56 // I
replace wz08_1b_imp = 10 if wz08_2_imp>=58 & wz08_2_imp<=63 // J
replace wz08_1b_imp = 11 if wz08_2_imp>=64 & wz08_2_imp<=66 // K
replace wz08_1b_imp = 12 if wz08_2_imp==68 // L
replace wz08_1b_imp = 13 if wz08_2_imp>=69 & wz08_2_imp<=75 // M
replace wz08_1b_imp = 14 if wz08_2_imp>=77 & wz08_2_imp<=82 // N
replace wz08_1b_imp = 15 if wz08_2_imp==84 // O
replace wz08_1b_imp = 16 if wz08_2_imp==85 // P
replace wz08_1b_imp = 17 if wz08_2_imp>=86 & wz08_2_imp<=88 // Q
replace wz08_1b_imp = 18 if wz08_2_imp>=90 & wz08_2_imp<=93 // R
replace wz08_1b_imp = 19 if wz08_2_imp>=94 & wz08_2_imp<=96 // S
replace wz08_1b_imp = 20 if wz08_2_imp>=97 & wz08_2_imp<=98 // T
replace wz08_1b_imp = 21 if wz08_2_imp==99 // U

quietly do "$prog\WZ08-1B.do"
label values wz08_1b_imp wz08_1b
format %50.0f wz08_1b_imp

tab wz08_1b_imp, m


*WZ08-1A industries (10 large sections)

gen wz08_1a_imp = . 
replace wz08_1a_imp =  1 if wz08_2_imp>= 1 & wz08_2_imp<= 3 // A
replace wz08_1a_imp =  2 if wz08_2_imp>= 5 & wz08_2_imp<=39 // B, C, D & E
replace wz08_1a_imp =  3 if wz08_2_imp>=41 & wz08_2_imp<=43 // F
replace wz08_1a_imp =  4 if wz08_2_imp>=45 & wz08_2_imp<=56 // G, H & I
replace wz08_1a_imp =  5 if wz08_2_imp>=58 & wz08_2_imp<=63 // J
replace wz08_1a_imp =  6 if wz08_2_imp>=64 & wz08_2_imp<=66 // K
replace wz08_1a_imp =  7 if wz08_2_imp==68 // L
replace wz08_1a_imp =  8 if wz08_2_imp>=69 & wz08_2_imp<=82 // M & N
replace wz08_1a_imp =  9 if wz08_2_imp>=84 & wz08_2_imp<=88 // O, P & Q
replace wz08_1a_imp = 10 if wz08_2_imp>=90 & wz08_2_imp<=99 // R, S, T & U

quietly do "$prog\WZ08-1A.do"
label values wz08_1a_imp wz08_1a
format %50.0f wz08_1a_imp

tab wz08_1a_imp, m



label variable wz08_5_imp "Industrial Subclass (WZ08-5)"
label variable wz08_4_imp "Industrial Class (WZ08-4)"
label variable wz08_3_imp "Industrial Group (WZ08-3)"
label variable wz08_2_imp "Industrial Division (WZ08-2)"
label variable wz08_1c_imp "Small Industrial Section (WZ08-1C)"
label variable wz08_1b_imp "Industrial Section (WZ08-1B)"
label variable wz08_1a_imp "Large Industrial Section (WZ08-1A)"

*drop wz08_5_imp wz08_4_imp wz08_3_imp wz08_1c_imp wz08_1b_imp wz08_1a_imp

compress wz08_*





*** (M) OCCUPATION (KLDB 2010) ***



*KldB10-5 occupations (1,300 occupational types or detailed occupational sub-groups)


rename beh_beruf_kldb10_num kldb10_5_imp

*tab kldb10_5_imp, m
recode kldb10_5_imp (-9=.) (-8=.) (-7=.) (-6=.) (-5=.)

quietly do "$prog\KldB10-5 (v2020).do"
label values kldb10_5_imp kldb10_5
format %50.0f kldb10_5_imp

tab kldb10_5_imp, m







*KldB10-4 occupations (700 occupational sub-groups)

gen kldb10_4_imp = floor(kldb10_5_imp/10) 

quietly do "$prog\KldB10-4 (v2020).do"
label values kldb10_4_imp kldb10_4
format %50.0f kldb10_4_imp

tab kldb10_4_imp, m





*KldB10-3 occupations (144 occupational groups)

gen kldb10_3_imp = floor(kldb10_4_imp/10) 

quietly do "$prog\KldB10-3 (v2020).do"
label values kldb10_3_imp kldb10_3
format %50.0f kldb10_3_imp

tab kldb10_3_imp, m




*KldB10-3 occupations + requirement level (436 detailed occupational groups)


gen level = mod(kldb10_5_imp, 10)
tostring level, replace

label variable level "Level of Requirement"

gen kldb10_35_imp = floor(kldb10_4_imp/10) 
tostring kldb10_35_imp, replace

replace kldb10_35_imp = kldb10_35_imp + level

destring kldb10_35_imp, replace force

quietly do "$prog\KldB10-35 (v2020).do"
label values kldb10_35_imp kldb10_35
format %50.0f kldb10_35_imp

tab kldb10_35_imp, m

drop level



*KldB10-2 occupations (37 occupational main groups)


gen kldb10_2_imp = floor(kldb10_3_imp/10) 

quietly do "$prog\KldB10-2 (v2020).do"
label values kldb10_2_imp kldb10_2
format %50.0f kldb10_2_imp

tab kldb10_2_imp, m


*KldB10-2 occupations + requirement level (135 detailed occupational groups)


gen level = mod(kldb10_5_imp, 10)
tostring level, replace

label variable level "Level of Requirement"

gen kldb10_25_imp = floor(kldb10_3_imp/10) 
tostring kldb10_25_imp, replace

replace kldb10_25_imp = kldb10_25_imp + level

destring kldb10_25_imp, replace force

quietly do "$prog\KldB10-25 (v2020).do"
label values kldb10_25_imp kldb10_25
format %50.0f kldb10_25_imp

tab kldb10_25_imp, m

drop level






*KldB10-1C occupations (10 occupational areas)


gen kldb10_1c_imp = floor(kldb10_2_imp/10) 

quietly do "$prog\KldB10-1C (v2020).do"
label values kldb10_1c_imp kldb10_1c
format %50.0f kldb10_1c_imp

tab kldb10_1c_imp, m


*KldB10-1C occupations + requirement level (39 detailed occupational areas)


gen level = mod(kldb10_5_imp, 10)
tostring level, replace

label variable level "Level of Requirement"

gen kldb10_15_imp = floor(kldb10_2_imp/10) 
tostring kldb10_15_imp, replace

replace kldb10_15_imp = kldb10_15_imp + level

destring kldb10_15_imp, replace force

quietly do "$prog\KldB10-15 (v2020).do"
label values kldb10_15_imp kldb10_15
format %50.0f kldb10_15_imp

tab kldb10_15_imp, m

drop level






*KldB10-1B occupations (14 occupational segments)


gen kldb10_1b_imp = .
replace kldb10_1b_imp = 11 if ( kldb10_2_imp==11 | kldb10_2_imp==12  ) // agriculture, forestry and horticulture
replace kldb10_1b_imp = 12 if ( kldb10_2_imp==21 | kldb10_2_imp==22 | kldb10_2_imp==23 | kldb10_2_imp==24 | kldb10_2_imp==28 | kldb10_2_imp==93 ) // manufacturing
replace kldb10_1b_imp = 13 if ( kldb10_2_imp==25 | kldb10_2_imp==26 | kldb10_2_imp==27  ) // production technology
replace kldb10_1b_imp = 14 if ( kldb10_2_imp==31 | kldb10_2_imp==32 | kldb10_2_imp==33 | kldb10_2_imp==34 ) // building and interior construction
replace kldb10_1b_imp = 21 if ( kldb10_2_imp==29 | kldb10_2_imp==63  ) // food, gastronomy and tourism
replace kldb10_1b_imp = 22 if ( kldb10_2_imp==81 | kldb10_2_imp==82  ) // health care
replace kldb10_1b_imp = 23 if ( kldb10_2_imp==83 | kldb10_2_imp==84 | kldb10_2_imp==91 | kldb10_2_imp==94 ) // social sector and cultural work 
replace kldb10_1b_imp = 31 if ( kldb10_2_imp==61 | kldb10_2_imp==62  ) // commerce and trade
replace kldb10_1b_imp = 32 if ( kldb10_2_imp==71 ) // business management and organisation
replace kldb10_1b_imp = 33 if ( kldb10_2_imp==72 | kldb10_2_imp==73 | kldb10_2_imp==92 ) // business-related services 
replace kldb10_1b_imp = 41 if ( kldb10_2_imp==41 | kldb10_2_imp==42 | kldb10_2_imp==43 ) // IT and natural sciences
replace kldb10_1b_imp = 51 if ( kldb10_2_imp==53 | kldb10_2_imp== 1 ) // safety and security
replace kldb10_1b_imp = 52 if ( kldb10_2_imp==51 | kldb10_2_imp==52 ) // traffic and logistics
replace kldb10_1b_imp = 53 if ( kldb10_2_imp==54 ) // cleaning

quietly do "$prog\KldB10-1B (v2020).do"
label values kldb10_1b_imp kldb10_1b
format %50.0f kldb10_1b_imp

tab kldb10_1b_imp, m



*KldB10-1A occupations (5 occupational sectors)

gen kldb10_1a_imp = floor(kldb10_1b_imp/10) 

quietly do "$prog\KldB10-1A (v2020).do"
label values kldb10_1a_imp kldb10_1a
format %50.0f kldb10_1a_imp

tab kldb10_1a_imp, m




label variable kldb10_5_imp "Occupational Type (KldB10-5)"
label variable kldb10_4_imp "Occupational Sub-Group (KldB10-4)"
label variable kldb10_3_imp "Occupational Group (KldB10-3)"
label variable kldb10_2_imp "Occupational Main Group (KldB10-2)"
label variable kldb10_1c_imp "Occupational Area (KldB10-1C)"
label variable kldb10_1b_imp "Occupational Segment (KldB10-1B)"
label variable kldb10_1a_imp "Occupational Sector (KldB10-1A)"

label variable kldb10_35_imp "Detailed Occupational Group (KldB10-35)"
label variable kldb10_25_imp "Detailed Occupational Main Group (KldB10-25)"
label variable kldb10_15_imp "Detailed Occupational Area (KldB10-15)"


compress kldb10_*






*** (O) REGION ***



*NUTS07-3 regions (401 districts)


rename e_krs_schl_ao_akt_num nuts07_3 // place of work 

*tab nuts07_3, m
recode nuts07_3 (-9=.) (-8=.) (-7=.) (-6=.) (-5=.) (20000=.)


quietly do "$prog\NUTS07-3.do"
label values nuts07_3 nuts07_3
format %50.0f nuts07_3

tab nuts07_3, m





*NUTS07-2 regions (38 government regions)

gen nuts07_2 = floor(nuts07_3/100) 

quietly do "$prog\NUTS07-2.do"
label values nuts07_2 nuts07_2
format %50.0f nuts07_2

tab nuts07_2, m




*NUTS07-1 regions (16 federal states)

gen nuts07_1 = floor(nuts07_2/10) 

quietly do "$prog\NUTS07-1.do"
label values nuts07_1 nuts07_1


tab nuts07_1, m







*commuting zones by Kosfeld/Werner (2012)

gen ram = .


replace ram =   4 if nuts07_3==1001 // Flensburg, City
replace ram =   1 if nuts07_3==1002 // Kiel, City
replace ram =   2 if nuts07_3==1003 // Luebeck, City
replace ram =   1 if nuts07_3==1004 // Neumuenster, City
replace ram =   3 if nuts07_3==1051 // Dithmarschen, District
replace ram =   5 if nuts07_3==1053 // Herzogtum Lauenburg, District
replace ram =   4 if nuts07_3==1054 // Nordfriesland, District
replace ram =   2 if nuts07_3==1055 // Ostholstein, District
replace ram =   5 if nuts07_3==1056 // Pinneberg, District
replace ram =   1 if nuts07_3==1057 // Ploen, District
replace ram =   1 if nuts07_3==1058 // Rendsburg-Eckernfoerde, District
replace ram =   4 if nuts07_3==1059 // Schleswig-Flensburg, District
replace ram =   5 if nuts07_3==1060 // Segeberg, District
replace ram =   5 if nuts07_3==1061 // Steinburg, District
replace ram =   5 if nuts07_3==1062 // Stormarn, District

replace ram =   5 if nuts07_3==2000 // Hamburg, City

replace ram =   6 if nuts07_3==3101 // Braunschweig, City
replace ram =   6 if nuts07_3==3102 // Salzgitter, City
replace ram =   7 if nuts07_3==3103 // Wolfsburg, City
replace ram =   7 if nuts07_3==3151 // Gifhorn, District
replace ram =   8 if nuts07_3==3152 // Goettingen, District (Dissolved)
replace ram =   9 if nuts07_3==3153 // Goslar, District
replace ram =   7 if nuts07_3==3154 // Helmstedt, District
replace ram =   8 if nuts07_3==3155 // Northeim, District
replace ram =   9 if nuts07_3==3156 // Osterode am Harz, District (Dissolved)
replace ram =   6 if nuts07_3==3157 // Peine, District
replace ram =   6 if nuts07_3==3158 // Wolfenbuettel, District
replace ram =   8 if nuts07_3==3159 // Goettingen, District
replace ram =  10 if nuts07_3==3241 // Region Hanover
replace ram =  22 if nuts07_3==3251 // Diepholz, District
replace ram =  11 if nuts07_3==3252 // Hameln-Pyrmont, District
replace ram =  10 if nuts07_3==3254 // Hildesheim, District
replace ram =  11 if nuts07_3==3255 // Holzminden, District
replace ram =  36 if nuts07_3==3256 // Nienburg (Weser), District
replace ram =  10 if nuts07_3==3257 // Schaumburg, District
replace ram =  12 if nuts07_3==3351 // Celle, District
replace ram =  23 if nuts07_3==3352 // Cuxhaven, District
replace ram =   5 if nuts07_3==3353 // Harburg, District
replace ram =  13 if nuts07_3==3354 // Luechow-Dannenberg, District
replace ram =   5 if nuts07_3==3355 // Lueneburg, District
replace ram =  22 if nuts07_3==3356 // Osterholz, District
replace ram =  22 if nuts07_3==3357 // Rotenburg (Wuemme), District
replace ram =  10 if nuts07_3==3358 // Heidekreis (Soltau-Fallingbostel)
replace ram =  14 if nuts07_3==3359 // Stade, District
replace ram =  15 if nuts07_3==3360 // Uelzen, District
replace ram =  22 if nuts07_3==3361 // Verden, District
replace ram =  22 if nuts07_3==3401 // Delmenhorst, City
replace ram =  16 if nuts07_3==3402 // Emden, City
replace ram =  17 if nuts07_3==3403 // Oldenburg, City
replace ram =  18 if nuts07_3==3404 // Osnabrueck, City
replace ram =  20 if nuts07_3==3405 // Wilhelmshaven, City
replace ram =  17 if nuts07_3==3451 // Ammerland, District
replace ram =  16 if nuts07_3==3452 // Aurich, District
replace ram =  21 if nuts07_3==3453 // Cloppenburg, District
replace ram =  19 if nuts07_3==3454 // Emsland, District
replace ram =  20 if nuts07_3==3455 // Friesland, District
replace ram =  19 if nuts07_3==3456 // Grafschaft Bentheim
replace ram =  16 if nuts07_3==3457 // Leer, District
replace ram =  17 if nuts07_3==3458 // Oldenburg, District
replace ram =  18 if nuts07_3==3459 // Osnabrueck, District
replace ram =  21 if nuts07_3==3460 // Vechta, District
replace ram =  17 if nuts07_3==3461 // Wesermarsch, District
replace ram =  20 if nuts07_3==3462 // Wittmund, District

replace ram =  22 if nuts07_3==4011 // Bremen, City
replace ram =  23 if nuts07_3==4012 // Bremerhaven, City

replace ram =  24 if nuts07_3==5111 // Duesseldorf, City
replace ram =  25 if nuts07_3==5112 // Duisburg, City
replace ram =  25 if nuts07_3==5113 // Essen, City
replace ram =  24 if nuts07_3==5114 // Krefeld, City
replace ram =  24 if nuts07_3==5116 // Moenchengladbach, City
replace ram =  25 if nuts07_3==5117 // Muelheim an der Ruhr, City
replace ram =  25 if nuts07_3==5119 // Oberhausen, City
replace ram =  26 if nuts07_3==5120 // Remscheid, City
replace ram =  26 if nuts07_3==5122 // Solingen, City
replace ram =  26 if nuts07_3==5124 // Wuppertal, City
replace ram =  27 if nuts07_3==5154 // Cleves, District
replace ram =  24 if nuts07_3==5158 // Mettmann, District
replace ram =  24 if nuts07_3==5162 // Rhein-Kreis Neuss
replace ram =  24 if nuts07_3==5166 // Viersen, District
replace ram =  25 if nuts07_3==5170 // Wesel, District
replace ram =  30 if nuts07_3==5313 // Aachen, City (Dissolved)
replace ram =  28 if nuts07_3==5314 // Bonn, City
replace ram =  29 if nuts07_3==5315 // Cologne, City
replace ram =  29 if nuts07_3==5316 // Leverkusen, City
replace ram =  30 if nuts07_3==5334 // Region Aachen
replace ram =  30 if nuts07_3==5354 // Aachen, District (Dissolved)
replace ram =  30 if nuts07_3==5358 // Dueren, District
replace ram =  29 if nuts07_3==5362 // Rhein-Erft-Kreis
replace ram =  29 if nuts07_3==5366 // Euskirchen, District
replace ram =  30 if nuts07_3==5370 // Heinsberg, District
replace ram =  31 if nuts07_3==5374 // Oberbergischer Kreis
replace ram =  29 if nuts07_3==5378 // Rheinisch-Bergischer Kreis
replace ram =  28 if nuts07_3==5382 // Rhein-Sieg-Kreis
replace ram =  25 if nuts07_3==5512 // Bottrop, City
replace ram =  37 if nuts07_3==5513 // Gelsenkirchen, City
replace ram =  32 if nuts07_3==5515 // Muenster, City
replace ram =  33 if nuts07_3==5554 // Borken, District
replace ram =  32 if nuts07_3==5558 // Coesfeld, District
replace ram =  37 if nuts07_3==5562 // Recklinghausen, District
replace ram =  32 if nuts07_3==5566 // Steinfurt, District
replace ram =  32 if nuts07_3==5570 // Warendorf, District
replace ram =  34 if nuts07_3==5711 // Bielefeld, City
replace ram =  34 if nuts07_3==5754 // Guetersloh, District
replace ram =  36 if nuts07_3==5758 // Herford, District
replace ram =  35 if nuts07_3==5762 // Hoexter, District
replace ram =  34 if nuts07_3==5766 // Lippe, District
replace ram =  36 if nuts07_3==5770 // Minden-Luebbecke, District
replace ram =  41 if nuts07_3==5774 // Paderborn, District
replace ram =  37 if nuts07_3==5911 // Bochum, City
replace ram =  38 if nuts07_3==5913 // Dortmund, City
replace ram =  39 if nuts07_3==5914 // Hagen, City
replace ram =  38 if nuts07_3==5915 // Hamm, City
replace ram =  37 if nuts07_3==5916 // Herne, City
replace ram =  39 if nuts07_3==5954 // Ennepe-Ruhr-Kreis
replace ram =  41 if nuts07_3==5958 // Hochsauerlandkreis
replace ram =  39 if nuts07_3==5962 // Maerkischer Kreis
replace ram =  31 if nuts07_3==5966 // Olpe, District
replace ram =  40 if nuts07_3==5970 // Siegen-Wittgenstein, District
replace ram =  41 if nuts07_3==5974 // Soest, District
replace ram =  38 if nuts07_3==5978 // Unna, District

replace ram =  42 if nuts07_3==6411 // Darmstadt, City
replace ram =  43 if nuts07_3==6412 // Frankfurt am Main, City
replace ram =  43 if nuts07_3==6413 // Offenbach am Main, City
replace ram =  58 if nuts07_3==6414 // Wiesbaden, City
replace ram =  66 if nuts07_3==6431 // Bergstrasse, District
replace ram =  42 if nuts07_3==6432 // Darmstadt-Dieburg, District
replace ram =  43 if nuts07_3==6433 // Gross-Gerau, District
replace ram =  43 if nuts07_3==6434 // Hochtaunuskreis
replace ram =  43 if nuts07_3==6435 // Main-Kinzig-Kreis
replace ram =  43 if nuts07_3==6436 // Main-Taunus-Kreis
replace ram =  42 if nuts07_3==6437 // Odenwaldkreis
replace ram =  43 if nuts07_3==6438 // Offenbach, District
replace ram =  45 if nuts07_3==6439 // Rheingau-Taunus-Kreis
replace ram =  43 if nuts07_3==6440 // Wetteraukreis, District
replace ram =  44 if nuts07_3==6531 // Giessen, District
replace ram =  44 if nuts07_3==6532 // Lahn-Dill-Kreis
replace ram =  45 if nuts07_3==6533 // Limburg-Weilburg, District
replace ram =  44 if nuts07_3==6534 // Marburg-Biedenkopf, District
replace ram =  47 if nuts07_3==6535 // Vogelsbergkreis
replace ram =  46 if nuts07_3==6611 // Kassel, City
replace ram =  47 if nuts07_3==6631 // Fulda, District
replace ram =  47 if nuts07_3==6632 // Hersfeld-Rotenburg, District
replace ram =  46 if nuts07_3==6633 // Kassel, District
replace ram =  46 if nuts07_3==6634 // Schwalm-Eder-Kreis
replace ram =  48 if nuts07_3==6635 // Waldeck-Frankenberg, District
replace ram =  46 if nuts07_3==6636 // Werra-Meissner-Kreis

replace ram =  49 if nuts07_3==7111 // Koblenz, City
replace ram =  28 if nuts07_3==7131 // Ahrweiler, District
replace ram =  50 if nuts07_3==7132 // Altenkirchen (Westerwald), District
replace ram =  51 if nuts07_3==7133 // Bad Kreuznach, District
replace ram =  51 if nuts07_3==7134 // Birkenfeld, District
replace ram =  49 if nuts07_3==7135 // Cochem-Zell, District
replace ram =  49 if nuts07_3==7137 // Mayen-Koblenz, District
replace ram =  49 if nuts07_3==7138 // Neuwied, District
replace ram =  49 if nuts07_3==7140 // Rhein-Hunsrueck-Kreis
replace ram =  49 if nuts07_3==7141 // Rhein-Lahn-Kreis
replace ram =  49 if nuts07_3==7143 // Westerwaldnutskreis
replace ram =  54 if nuts07_3==7211 // Trier, City
replace ram =  54 if nuts07_3==7231 // Bernkastel-Wittlich, District
replace ram =  52 if nuts07_3==7232 // Eifelkreis Bitburg-Pruem, District
replace ram =  53 if nuts07_3==7233 // Vulkaneifel, District
replace ram =  54 if nuts07_3==7235 // Trier-Saarburg, District
replace ram =  57 if nuts07_3==7311 // Frankenthal (Pfalz), City
replace ram =  55 if nuts07_3==7312 // Kaiserslautern, City
replace ram =  56 if nuts07_3==7313 // Landau in der Pfalz, City
replace ram =  57 if nuts07_3==7314 // Ludwigshafen am Rhein, City
replace ram =  58 if nuts07_3==7315 // Mainz, City
replace ram =  57 if nuts07_3==7316 // Neustadt an der Weinstrasse, City
replace ram = 108 if nuts07_3==7317 // Pirmasens, City
replace ram =  57 if nuts07_3==7318 // Speyer, City
replace ram =  57 if nuts07_3==7319 // Worms, City
replace ram = 108 if nuts07_3==7320 // Zweibruecken, City
replace ram =  58 if nuts07_3==7331 // Alzey-Worms, District
replace ram =  57 if nuts07_3==7332 // Bad Duerkheim, District
replace ram =  55 if nuts07_3==7333 // Donnersbergkreis
replace ram =  56 if nuts07_3==7334 // Germersheim, District
replace ram =  55 if nuts07_3==7335 // Kaiserslautern, District
replace ram =  55 if nuts07_3==7336 // Kusel, District
replace ram =  56 if nuts07_3==7337 // Suedliche Weinstrasse, District
replace ram =  57 if nuts07_3==7338 // Rhein-Pfalz-Kreis
replace ram =  58 if nuts07_3==7339 // Mainz-Bingen, District
replace ram = 108 if nuts07_3==7340 // Suedwestpfalz, District

replace ram =  59 if nuts07_3==8111 // Stuttgart, City
replace ram =  60 if nuts07_3==8115 // Boeblingen, District
replace ram =  59 if nuts07_3==8116 // Esslingen, District
replace ram =  61 if nuts07_3==8117 // Goeppingen, District
replace ram =  59 if nuts07_3==8118 // Ludwigsburg, District
replace ram =  59 if nuts07_3==8119 // Rems-Murr-Kreis
replace ram =  62 if nuts07_3==8121 // Heilbronn, City
replace ram =  62 if nuts07_3==8125 // Heilbronn, District
replace ram =  62 if nuts07_3==8126 // Hohenlohekreis
replace ram =  63 if nuts07_3==8127 // Schwaebisch Hall, District
replace ram = 102 if nuts07_3==8128 // Main-Tauber-Kreis
replace ram =  64 if nuts07_3==8135 // Heidenheim, District
replace ram =  64 if nuts07_3==8136 // Ostalbkreis
replace ram =  65 if nuts07_3==8211 // Baden-Baden, City
replace ram =  65 if nuts07_3==8212 // Karlsruhe, City
replace ram =  65 if nuts07_3==8215 // Karlsruhe, District
replace ram =  65 if nuts07_3==8216 // Rastatt, District
replace ram =  66 if nuts07_3==8221 // Heidelberg, City
replace ram =  57 if nuts07_3==8222 // Mannheim, City
replace ram =  62 if nuts07_3==8225 // Neckar-Odenwald-Kreis
replace ram =  66 if nuts07_3==8226 // Rhein-Neckar-Kreis
replace ram =  67 if nuts07_3==8231 // Pforzheim, City
replace ram =  60 if nuts07_3==8235 // Calw, District
replace ram =  67 if nuts07_3==8236 // Enzkreis
replace ram =  60 if nuts07_3==8237 // Freudenstadt, District
replace ram =  68 if nuts07_3==8311 // Freiburg im Breisgau, City
replace ram =  68 if nuts07_3==8315 // Breisgau-Hochschwarzwald, District
replace ram =  68 if nuts07_3==8316 // Emmendingen, District
replace ram =  69 if nuts07_3==8317 // Ortenaukreis
replace ram =  70 if nuts07_3==8325 // Rottweil, District
replace ram =  70 if nuts07_3==8326 // Schwarzwald-Baar-Kreis
replace ram =  70 if nuts07_3==8327 // Tuttlingen, District
replace ram =  71 if nuts07_3==8335 // Konstanz, District
replace ram =  72 if nuts07_3==8336 // Loerrach, District
replace ram =  73 if nuts07_3==8337 // Waldshut, District
replace ram =  74 if nuts07_3==8415 // Reutlingen, District
replace ram =  74 if nuts07_3==8416 // Tuebingen, District
replace ram =  75 if nuts07_3==8417 // Zollernalbkreis
replace ram =  76 if nuts07_3==8421 // Ulm, City
replace ram =  76 if nuts07_3==8425 // Alb-Donau-Kreis
replace ram =  77 if nuts07_3==8426 // Biberach, District
replace ram =  77 if nuts07_3==8435 // Bodenseekreis
replace ram =  77 if nuts07_3==8436 // Ravensburg, District
replace ram =  78 if nuts07_3==8437 // Sigmaringen, District

replace ram =  79 if nuts07_3==9161 // Ingolstadt, City
replace ram =  80 if nuts07_3==9162 // Munich, City
replace ram =  82 if nuts07_3==9163 // Rosenheim, City
replace ram =  81 if nuts07_3==9171 // Altoetting, District
replace ram =  82 if nuts07_3==9172 // Berchtesgadener Land, District
replace ram =  80 if nuts07_3==9173 // Bad Toelz-Wolfratshausen, District
replace ram =  80 if nuts07_3==9174 // Dachau, District
replace ram =  80 if nuts07_3==9175 // Ebersberg, District
replace ram =  79 if nuts07_3==9176 // Eichstaett, District
replace ram =  80 if nuts07_3==9177 // Erding, District
replace ram =  80 if nuts07_3==9178 // Freising, District
replace ram =  80 if nuts07_3==9179 // Fuerstenfeldbruck, District
replace ram =  83 if nuts07_3==9180 // Garmisch-Partenkirchen, District
replace ram =  80 if nuts07_3==9181 // Landsberg am Lech, District
replace ram =  80 if nuts07_3==9182 // Miesbach, District
replace ram =  81 if nuts07_3==9183 // Muehldorf am Inn, District
replace ram =  80 if nuts07_3==9184 // Munich, District
replace ram =  79 if nuts07_3==9185 // Neuburg-Schrobenhausen, District
replace ram =  79 if nuts07_3==9186 // Pfaffenhofen an der Ilm, District
replace ram =  82 if nuts07_3==9187 // Rosenheim, District
replace ram =  80 if nuts07_3==9188 // Starnberg, District
replace ram =  82 if nuts07_3==9189 // Traunstein, District
replace ram =  83 if nuts07_3==9190 // Weilheim-Schongau, District
replace ram =  87 if nuts07_3==9261 // Landshut, City
replace ram =  86 if nuts07_3==9262 // Passau, City
replace ram =  87 if nuts07_3==9263 // Straubing, City
replace ram =  84 if nuts07_3==9271 // Deggendorf, District
replace ram =  85 if nuts07_3==9272 // Freyung-Grafenau, District
replace ram =  90 if nuts07_3==9273 // Kelheim, District
replace ram =  87 if nuts07_3==9274 // Landshut, District
replace ram =  86 if nuts07_3==9275 // Passau, District
replace ram =  84 if nuts07_3==9276 // Regen, District
replace ram =  81 if nuts07_3==9277 // Rottal-Inn, District
replace ram =  87 if nuts07_3==9278 // Straubing-Bogen, District
replace ram =  87 if nuts07_3==9279 // Dingolfing-Landau, District
replace ram =  89 if nuts07_3==9361 // Amberg, City
replace ram =  90 if nuts07_3==9362 // Regensburg, City
replace ram =  89 if nuts07_3==9363 // Weiden in der Oberpfalz, City
replace ram =  89 if nuts07_3==9371 // Amberg-Sulzbach, District
replace ram =  88 if nuts07_3==9372 // Cham, District
replace ram =  97 if nuts07_3==9373 // Neumarkt in der Oberpfalz, District
replace ram =  89 if nuts07_3==9374 // Neustadt an der Waldnaab, District
replace ram =  90 if nuts07_3==9375 // Regensburg, District
replace ram =  90 if nuts07_3==9376 // Schwandorf, District
replace ram =  89 if nuts07_3==9377 // Tirschenreuth, District
replace ram =  91 if nuts07_3==9461 // Bamberg, City
replace ram =  92 if nuts07_3==9462 // Bayreuth, City
replace ram =  93 if nuts07_3==9463 // Coburg, City
replace ram =  94 if nuts07_3==9464 // Hof, City
replace ram =  91 if nuts07_3==9471 // Bamberg, District
replace ram =  92 if nuts07_3==9472 // Bayreuth, District
replace ram =  93 if nuts07_3==9473 // Coburg, District
replace ram =  96 if nuts07_3==9474 // Forchheim, District
replace ram =  94 if nuts07_3==9475 // Hof, District
replace ram =  95 if nuts07_3==9476 // Kronach, District
replace ram =  92 if nuts07_3==9477 // Kulmbach, District
replace ram =  93 if nuts07_3==9478 // Lichtenfels, District
replace ram =  94 if nuts07_3==9479 // Wunsiedel im Fichtelgebirge, District
replace ram =  98 if nuts07_3==9561 // Ansbach, City
replace ram =  96 if nuts07_3==9562 // Erlangen, City
replace ram =  97 if nuts07_3==9563 // Fuerth, City
replace ram =  97 if nuts07_3==9564 // Nuremberg, City
replace ram =  97 if nuts07_3==9565 // Schwabach, City
replace ram =  98 if nuts07_3==9571 // Ansbach, District
replace ram =  96 if nuts07_3==9572 // Erlangen-Hoechstadt, District
replace ram =  97 if nuts07_3==9573 // Fuerth, District
replace ram =  97 if nuts07_3==9574 // Nuernberger Land, District
replace ram =  96 if nuts07_3==9575 // Neustadt an der Aisch-Bad Windsheim, District
replace ram =  97 if nuts07_3==9576 // Roth, District
replace ram =  99 if nuts07_3==9577 // Weissenburg-Gunzenhausen, District
replace ram = 100 if nuts07_3==9661 // Aschaffenburg, City
replace ram = 101 if nuts07_3==9662 // Schweinfurt, City
replace ram = 102 if nuts07_3==9663 // Wuerzburg, City
replace ram = 100 if nuts07_3==9671 // Aschaffenburg, District
replace ram = 101 if nuts07_3==9672 // Bad Kissingen, District
replace ram = 101 if nuts07_3==9673 // Rhoen-Grabfeld, District
replace ram =  91 if nuts07_3==9674 // Hassberge, District
replace ram = 102 if nuts07_3==9675 // Kitzingen, District
replace ram = 100 if nuts07_3==9676 // Miltenberg, District
replace ram = 102 if nuts07_3==9677 // Main-Spessart, District
replace ram = 101 if nuts07_3==9678 // Schweinfurt, District
replace ram = 102 if nuts07_3==9679 // Wuerzburg, District
replace ram = 103 if nuts07_3==9761 // Augsburg, City
replace ram = 106 if nuts07_3==9762 // Kaufbeuren, City
replace ram = 106 if nuts07_3==9763 // Kempten (Allgaeu), City
replace ram = 104 if nuts07_3==9764 // Memmingen, City
replace ram = 103 if nuts07_3==9771 // Aichach-Friedberg, District
replace ram = 103 if nuts07_3==9772 // Augsburg, District
replace ram =  64 if nuts07_3==9773 // Dillingen an der Donau, District
replace ram =  76 if nuts07_3==9774 // Guenzburg, District
replace ram =  76 if nuts07_3==9775 // Neu-Ulm, District
replace ram =  77 if nuts07_3==9776 // Lindau (Bodensee), District
replace ram = 106 if nuts07_3==9777 // Ostallgaeu, District
replace ram = 104 if nuts07_3==9778 // Unterallgaeu, District
replace ram = 105 if nuts07_3==9779 // Donau-Ries, District
replace ram = 106 if nuts07_3==9780 // Oberallgaeu, District

replace ram = 107 if nuts07_3==10041 // Region Saarbruecken
replace ram = 107 if nuts07_3==10042 // Merzig-Wadern, District
replace ram = 107 if nuts07_3==10043 // Neunkirchen, District
replace ram = 107 if nuts07_3==10044 // Saarlouis, District
replace ram = 108 if nuts07_3==10045 // Saarpfalz-Kreis
replace ram = 107 if nuts07_3==10046 // Sankt Wendel, District

replace ram = 109 if nuts07_3==11000 // Berlin, City

replace ram = 116 if nuts07_3==12051 // Brandenburg an der Havel, City
replace ram = 118 if nuts07_3==12052 // Cottbus, City
replace ram = 110 if nuts07_3==12053 // Frankfurt (Oder), City
replace ram = 109 if nuts07_3==12054 // Potsdam, City
replace ram = 109 if nuts07_3==12060 // Barnim, District
replace ram = 109 if nuts07_3==12061 // Dahme-Spreewald, District
replace ram = 111 if nuts07_3==12062 // Elbe-Elster, District
replace ram = 112 if nuts07_3==12063 // Havelland, District
replace ram = 113 if nuts07_3==12064 // Maerkisch-Oderland, District
replace ram = 114 if nuts07_3==12065 // Oberhavel, District
replace ram = 111 if nuts07_3==12066 // Oberspreewald-Lausitz, District
replace ram = 110 if nuts07_3==12067 // Oder-Spree, District
replace ram = 115 if nuts07_3==12068 // Ostprignitz-Ruppin, District
replace ram = 116 if nuts07_3==12069 // Potsdam-Mittelmark, District
replace ram = 117 if nuts07_3==12070 // Prignitz, District
replace ram = 118 if nuts07_3==12071 // Spree-Neisse, District
replace ram = 119 if nuts07_3==12072 // Teltow-Flaeming, District
replace ram = 120 if nuts07_3==12073 // Uckermark, District

replace ram = 123 if nuts07_3==13003 // Rostock, City
replace ram = 121 if nuts07_3==13004 // Schwerin, City
replace ram = 122 if nuts07_3==13071 // Mecklenburgische Seenplatte, District
replace ram = 123 if nuts07_3==13072 // Rostock (Mittleres Mecklenburg), District
replace ram = 124 if nuts07_3==13073 // Vorpommern-Ruegen (Nordvorpommern), District
replace ram = 121 if nuts07_3==13074 // Nordwestmecklenburg, District
replace ram = 125 if nuts07_3==13075 // Vorpommern-Greifswald (Südvorpommern), District
replace ram = 121 if nuts07_3==13076 // Ludwigslust-Parchim (Südwestmecklenburg), District 

replace ram = 126 if nuts07_3==14511 // Chemnitz, City
replace ram = 126 if nuts07_3==14521 // Erzgebirgskreis
replace ram = 126 if nuts07_3==14522 // Mittelsachsen, District
replace ram =  94 if nuts07_3==14523 // Vogtlandkreis
replace ram = 126 if nuts07_3==14524 // Zwickau, District
replace ram = 127 if nuts07_3==14612 // Dresden, City
replace ram = 128 if nuts07_3==14625 // Bautzen, District
replace ram = 128 if nuts07_3==14626 // Goerlitz, District
replace ram = 127 if nuts07_3==14627 // Meissen, District
replace ram = 127 if nuts07_3==14628 // Saechsische Schweiz-Osterzgebirge, District
replace ram = 129 if nuts07_3==14713 // Leipzig, City
replace ram = 129 if nuts07_3==14729 // Leipzig, District
replace ram = 129 if nuts07_3==14730 // Nordsachsen, District

replace ram = 130 if nuts07_3==15001 // Dessau-Rosslau, City
replace ram = 132 if nuts07_3==15002 // Halle (Saale), City
replace ram = 131 if nuts07_3==15003 // Magdeburg, City
replace ram =  13 if nuts07_3==15081 // Altmarkkreis Salzwedel
replace ram = 130 if nuts07_3==15082 // Anhalt-Bitterfeld, District
replace ram = 131 if nuts07_3==15083 // Boerde, District
replace ram = 132 if nuts07_3==15084 // Burgenlandkreis
replace ram =   9 if nuts07_3==15085 // Harz, District
replace ram = 131 if nuts07_3==15086 // Jerichower Land, District
replace ram = 132 if nuts07_3==15087 // Mansfeld-Suedharz, District
replace ram = 132 if nuts07_3==15088 // Saalekreis
replace ram = 131 if nuts07_3==15089 // Salzlandkreis
replace ram = 133 if nuts07_3==15090 // Stendal, District
replace ram = 130 if nuts07_3==15091 // Wittenberg, District

replace ram = 134 if nuts07_3==16051 // Erfurt, City
replace ram = 135 if nuts07_3==16052 // Gera, City
replace ram = 136 if nuts07_3==16053 // Jena, City
replace ram = 140 if nuts07_3==16054 // Suhl, City
replace ram = 134 if nuts07_3==16055 // Weimar, City
replace ram = 138 if nuts07_3==16056 // Eisenach, City (Dissolved)
replace ram =   8 if nuts07_3==16061 // Eichsfeld, District
replace ram = 137 if nuts07_3==16062 // Nordhausen, District
replace ram = 138 if nuts07_3==16063 // Wartburgkreis
replace ram = 139 if nuts07_3==16064 // Unstrut-Hainich-Kreis
replace ram = 137 if nuts07_3==16065 // Kyffhaeuserkreis
replace ram = 140 if nuts07_3==16066 // Schmalkalden-Meiningen, District
replace ram = 134 if nuts07_3==16067 // Gotha, District
replace ram = 134 if nuts07_3==16068 // Soemmerda, District
replace ram = 140 if nuts07_3==16069 // Hildburghausen, District
replace ram = 134 if nuts07_3==16070 // Ilm-Kreis
replace ram = 134 if nuts07_3==16071 // Weimarer Land, District
replace ram =  93 if nuts07_3==16072 // Sonneberg, District
replace ram = 141 if nuts07_3==16073 // Saalfeld-Rudolstadt, District
replace ram = 136 if nuts07_3==16074 // Saale-Holzland-Kreis
replace ram = 141 if nuts07_3==16075 // Saale-Orla-Kreis
replace ram = 135 if nuts07_3==16076 // Greiz, Kreis
replace ram = 135 if nuts07_3==16077 // Altenburger Land, District


quietly do "$prog\RAM.do"
label values ram ram
format %25.0f ram

tab ram, m



*LAU17 regions (10,785 municipalities, but only 10,773 are essentially filled)


tab e_gem_schl_ao_akt_num if e_gem_schl_ao_akt_num<0, m

recode e_gem_schl_ao_akt_num  (-9=.) (-8=.) (-7=.) (-6=.) (-5=.) (20000000=.)

tab e_gem_schl_ao_akt_num if e_gem_schl_ao_akt_num<0, m


codebook e_gem_schl_ao_akt_num

rename e_gem_schl_ao_akt_num lau17






*West/East Germany  (2 territories)


tab ow_knz, m

rename ow_knz east
recode east (1=0) (2=1) (-9=.) (-8=.) (-7=.) (-6=.) (-5=.) (3=.)

tab east, m

label define east 0 "0 No" 1 "1 Yes" 
label values east east

tab east, m



label variable nuts07_3 "District (NUTS07-3)"
label variable nuts07_2 "Government Region (NUTS07-2)"
label variable nuts07_1 "Federal State (NUTS07-1)"
label variable lau17 "Municipality (LAU17)"
label variable ram "Commuting Zone from Kosfeld/Werner (2012)"
label variable east "Workplace in East Germany (incl. East Berlin) (0=No, 1=Yes)"



compress nuts07_* lau17 ram east // east

*drop if nuts07_3==. // do not drop to not bias hirings (when spell is dropped, next year's spell is artificially recognized as hire)

sort prs_id year betnr ieb_fall_id
order prs_id year betnr ieb_fall_id start end duration type parttime_imp age female educ_imp foreign wz08_5_imp kldb10_35_imp kldb10_25_imp kldb10_15_imp kldb10_5_imp kldb10_4_imp kldb10_3_imp kldb10_2_imp kldb10_1c_imp kldb10_1b_imp kldb10_1a_imp nuts07_3 nuts07_2 nuts07_1 lau17 ram east

**# Bookmark #1








*** (P) IMPUTED DAILY WAGES (OF REGULAR FULL-TIME WORKERS) ***


sum wage tegi


gen tegi_miss = ( tegi==. )

tab year tegi_miss, m
tab ist_imputiert tegi_miss, m

tab ist_imputiert if year>=1999, m // ~50.4 percent of observations do not enter imputation

*tab grund_teilzeit if year>=1999, m  // ~18.6 percent
*tab grund_geringfuegig if year>=1999, m  // ~31.5 percent
*tab grund_alter if year>=1999, m // ~2.7 percent 
*tab grund_ost_start if year>=1999, m // 0.0 percent (only before 1993)
*tab grund_nulls if year>=1999, m // ~0.01 percent 
*tab grund_duplikat if year>=1999, m // 0.0 percent (already deleted)
*tab grund_einmalzahlung if year>=1999, m // 0.0 percent  (already deleted)


count if wage_day==. // never missing
tab type ist_imputiert, m nofreq row // variable "tegi" is only filled for regular/other FT workers (type==1 or type==6), otherwise missing

gen wage_day_imp = wage_day
replace wage_day_imp = tegi if ist_imputiert==1

label variable wage_day_imp "Imputed Gross Daily Wage (w/ Special Payments)"



gen wage_imp = duration * wage_day_imp

label variable wage_imp "Imputed Gross Wage (w/ Special Payments)"


*hist aeeg
*drop if aeeg>...


drop wage_day tegi // aeeg 




sort betnr prs_id year ieb_fall_id  // ensure stable sorting with "ieb_fall_id" for reproducability







*** (R) WAGE BILL ***


sort betnr prs_id year


*disregard spells with duration of less than 30 days

gen wage_imp_adj = .
replace wage_imp_adj = wage_day_imp * duration if duration>=30
replace wage_imp_adj = 0 if duration<30


drop wage_imp 

rename wage_imp_adj wage_imp
label variable wage_imp "Imputed Gross Wage (w/ Special Payments, w/o Spells < 30 days)"


*calculate wage bill for worker-firm-year triple


sort betnr prs_id year

egen wage_bill_imp = total(wage_imp), by(betnr prs_id year)


label variable wage_bill_imp "Wage Bill"


save "$data\BeH_1123_V4.dta", replace







*** (R) EXTRACT RELEVANT INFLOW AND EMPLOYMENT SPELLS ***


*use "$data\BeH_1123_V4.dta", clear


keep betnr prs_id year ieb_fall_id type start end wage_day_imp duration wage_bill_imp 

sort betnr prs_id year ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability
order betnr prs_id year ieb_fall_id start end type wage_day_imp duration wage_bill_imp


*keep only most important spell for person-establishment-period triple

*note: spells with same occupation, region and type --> it does not matter for HHI computation which duplicate is dropped (0.08% of spells)

*duplicates report betnr year prs_id contract nuts07_3 kldb10_5_imp, force // without "ieb_fall_id"



*delete multiple employment relationships between person and a certain establishment within one year
*source: Ganzer et al. (2020, p.17)	


*delete multiple person-firm combinations within one year

by betnr prs_id year: gen multi = _N 
tab multi, m 

gen filter = 0


*1st step: delete spells shorter than 30 days

tab duration, m

replace filter = 1 if duration<30

preserve

	keep if filter==1
	
	keep betnr prs_id year ieb_fall_id filter
	
	save "$data\BeH_1123_V5.dta", replace
	
restore

drop if filter==1
tab filter, m

drop multi 
by betnr prs_id year: gen multi = _N 
tab multi, m 


*2nd step: delete marginal employment, if there is simultaneous non-marginal employment and marginal employment

by betnr prs_id year: egen nonmarginal = sum(type!=3)
tab nonmarginal, m

replace filter = 1 if type==3 & multi>=2 & nonmarginal>=1


preserve

	keep if filter==1
	
	keep betnr prs_id year ieb_fall_id filter
	
	save "$data\BeH_1123_V6.dta", replace
	
restore

drop if filter==1
tab filter, m

drop multi 
by betnr prs_id year: gen multi = _N 
tab multi, m 


*3rd step: select observation with highest value for "beh_tag_entgelt" (when there is a tie: select observation with higher duration)

sort betnr prs_id year ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability 

by betnr prs_id year: egen rank_w = rank(-wage_day_imp) // no missing rank values because of missing values
by betnr prs_id year: egen rank_d = rank(-duration) // no missing rank values because of missing values

order betnr prs_id year multi rank_w wage_day_imp rank_d duration
sort betnr prs_id year rank_w rank_d ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability 

by betnr prs_id year: gen rank = _n
order betnr prs_id year rank
sort betnr prs_id year rank ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability 

replace filter = 1 if rank!=1 

preserve

	keep if filter==1
	
	keep betnr prs_id year ieb_fall_id filter
	
	save "$data\BeH_1123_V7.dta", replace
	
restore

drop if filter==1
tab filter, m

drop multi 
by betnr prs_id year: gen multi = _N 
tab multi, m // each person-establishment-year triple enters the data only once

drop rank* multi nonmarginal wage_day_imp duration start end type 

	
*define inflows

bysort betnr prs_id year: gen N = _N // note: this routine requires that there is only one spell per establishment-person-year triple
tab N, m
drop N

bysort betnr prs_id (year): gen n = _n // number of observations per person within establishment
tab n, m

gen inflow = 0 

bysort betnr prs_id (year): replace inflow = 1 if n==1 // first employment for certain establishment (from 2011 onwards)
bysort betnr prs_id (year): replace inflow = 1 if n!=1 & !missing(n) & year[_n-1]+1!=year[_n] // another recruitment by the same establishment in later years
replace inflow = . if year==2011 // reason: observations in 2011 are always "hired" by construction as this is the first year in the data extract --> this year must be removed later on

drop n

label variable inflow "Inflow (0=No, 1=Yes)"

label define inflow 0 "0 No" 1 "1 Yes" 
label values inflow inflow

tab inflow, m

tab filter, m




*define employment

tab filter, m

gen employment = 1

label variable employment "Employment (0=No, 1=Yes)"

label define employment 0 "0 No" 1 "1 Yes" 
label values employment employment

tab employment, m

tab filter, m




*define wage bill



tab filter, m

*gen wage_bill_imp = wage if employment = 1

label variable wage_bill_imp "Wage Bill"

sum wage_bill_imp

tab filter, m




*append and correct eliminated spells

append using "$data\BeH_1123_V5.dta"
append using "$data\BeH_1123_V6.dta"
append using "$data\BeH_1123_V7.dta"

keep betnr prs_id year ieb_fall_id filter inflow employment wage_bill_imp

tab filter, m

replace inflow = 0 if filter==1 & year!=2011
replace inflow = . if filter==1 & year==2011
tab filter inflow, m


replace employment = 0 if filter==1 
tab filter employment, m


replace wage_bill_imp = 0 if filter==1 
sum wage_bill_imp if filter==0
sum wage_bill_imp if filter==1


keep ieb_fall_id inflow employment wage_bill_imp

sort ieb_fall_id



save "$data\BeH_1123_V8.dta", replace







































use "$data\BeH_1123_V4.dta", clear


sort ieb_fall_id

drop wage_bill_imp


merge 1:1 ieb_fall_id using "$data\BeH_1123_V8.dta", keepusing(inflow employment wage_bill_imp)
drop _merge


sort prs_id betnr year ieb_fall_id



save "$data\BeH_1123_V9.dta", replace

tab employment inflow if year>=2012, m nofreq cell

erase "$data\BeH_1123_V4.dta"
erase "$data\BeH_1123_V5.dta"
erase "$data\BeH_1123_V6.dta"
erase "$data\BeH_1123_V7.dta"
erase "$data\BeH_1123_V8.dta"




**# Bookmark #2







*** 1.2.6 RELEVANT EMPLOYMENT SPELLS ***


use "$data\BeH_1123_V9.dta", replace


tab employment inflow if year>=2012, m nofreq cell
keep if employment==1

keep if inrange(year,2012,2023)

*when using hourly gross wages (after 1999):
*not relevant here

*when using hourly gross wages (before 1999):
*restrict to workers (FT & PT) in regular/other employment, apprentices and in partial retirement
*not relevant here

*when using daily gross wages: 
*further restrict to full-time workers in regular/other employment
*not relevant here

tab type, m
tab type parttime, m

*keep if (type==1 | type==2 | type==3 | type==4 | type==5 | type==6 | type==7 | type==. )

*keep if regoth==1
*keep if regothft==1


drop if type == .

*drop if duration==.

*drop if parttime_imp==.



*tab wz08_2_imp, m
*keep if (wz08_2_imp>=5 & wz08_2_imp<=82) | wz08_2_imp==90 | (wz08_2_imp>=92 & wz08_2_imp<=96)  // keep only non-agricultural business sector


*tab wz08_2_imp, m



*gen kldb10_5_imp_miss = (kldb10_5_imp==.)
*tab year kldb10_5_imp_miss, m nofreq row // many missings in 2010 and especially 2011, about 500,000 missings in 2012
*drop kldb10_5_imp_miss

*drop if kldb10_5_imp==.



*gen wz08_5_imp_miss = (wz08_5_imp==.)
*tab year wz08_5_imp_miss, m nofreq row 
*drop wz08_5_imp_miss

*drop if wz08_5_imp==.



*gen lau17_miss = (lau17==.)
*tab year lau17_miss, m 
*drop lau17_miss

*drop if lau17==.





keep prs_id year betnr ieb_fall_id type wz08_* kldb10_* nuts07_* lau17 ram employment inflow wage_bill_imp parttime_imp female educ_imp age foreign


sort prs_id year betnr ieb_fall_id
order prs_id year betnr ieb_fall_id type wz08_* kldb10_* nuts07_* lau17 ram employment inflow wage_bill_imp parttime_imp female educ_imp age foreign


compress

 
save "$data\BeH_1123.dta", replace






		


*** 1.3 LABOR MARKET CONCENTRATION: OCCUPATIONS ***


*** 1.3.1 PREPARE DATASET ***


*note: different X-digit KldB10 occupations add up to each other, i.e. each 5-digit KldB occupations belongs to exactly one 4-digit KldB occupation --> 1:1 relationship, i.e. collapse command can be simultaneously executed for different digits of KldB occupations
*note: different X-digit NACE/LAU regions add up to each other, i.e. each LAU region belongs to exactly one 3-digit NUTS region --> 1:1 relationship, i.e. collapse command can be simultaneously executed for different digits of NUTS regions



*create dataset with number of workers per occupation-region-firm-year combination



use "$data\BeH_1123.dta", replace 




gen kldb10_5_imp_miss = (kldb10_5_imp==.)
tab year kldb10_5_imp_miss, m nofreq row // many missings in 2010 and especially 2011, about 500,000 missings in 2012
drop kldb10_5_imp_miss

drop if kldb10_5_imp==.



gen lau17_miss = (lau17==.)
tab year lau17_miss, m 
drop lau17_miss

drop if lau17==.


rename kldb10_5_imp kldb10_45_imp
rename lau17 nuts07_4
rename ram nuts07_0


label variable kldb10_45_imp "Detailed Occupational Sub-Group (KldB10-45)"

tab year, m

keep if year>=2012 // note: KldB10 only available since 2012, inflows in 2011 cannot be measured (first year)
keep if year<=2023 // note: current edge of BeH data

drop if kldb10_45_imp==. // already deleted above
drop if nuts07_4==.  // already deleted above
	
tab type, m

gen inflow_mini = inflow
replace inflow_mini = 0 if type==3

gen employment_mini = employment
replace employment_mini = 0 if type==3

gen wage_bill_imp_mini = wage_bill_imp
replace wage_bill_imp_mini = 0 if type==3

gen kldb10_99_imp = 1 // always the same
gen nuts07_99 = 1 // always the same

collapse (sum) H_jt=inflow L_jt=employment W_jt=wage_bill_imp h_jt=inflow_mini l_jt=employment_mini w_jt=wage_bill_imp_mini ///
			   , by(betnr year kldb10_99_imp kldb10_15_imp kldb10_25_imp kldb10_35_imp kldb10_45_imp nuts07_99 nuts07_0 nuts07_1 nuts07_2 nuts07_3 nuts07_4)

   
*duplicates report betnr year // there are duplicates --> reason: each establishment-year observation can employ several different occupations; moreover: in this BeH version, in rare cases, some firms from different municipalities may have the same establishemt number --> treat them as different firms for consistency


save "$data\LMC_kldb_1223_V0.dta", replace 




*** 1.3.2 CALCULATE LABOR MARKET CONCENTRATION ***




local kldb 35 99 15 25 45
local nuts 0 99 1 2 3 4  

local flow H L W // h l w

foreach y of local kldb {


	
	if `"`y'"'=="35"  { // for 35-digit occupations: calculate HHI for all types of regions
			
				local nuts 0 99 1 2 3 4 
			}
			

	if `"`y'"'=="99" | `"`y'"'=="15" | `"`y'"'=="25" | `"`y'"'=="45"  { // for other types of occupations: calculate HHI for baseline type of region (#0)
			
				local nuts 0 // 99 1 2 3 4 
			}
	
	

	foreach z of local nuts {

		display "Calculate Labor Market Concentration: KldB10-`y' x NUTS07-`z'"
	
		quietly {

			use "$data\LMC_kldb_1223_V0.dta", clear
			
			keep betnr year kldb10_`y'_imp nuts07_`z' H_jt L_jt W_jt // h_jt l_jt w_jt 

			sort kldb10_`y'_imp nuts07_`z' year betnr
			order kldb10_`y'_imp nuts07_`z' year betnr H_jt L_jt W_jt // h_jt l_jt w_jt 
			
			
			bysort kldb10_`y'_imp nuts07_`z' year: egen H_`y'_`z' = total(H_jt) // number of hires per labor market --> necessary for computation of HHI
			bysort kldb10_`y'_imp nuts07_`z' year: egen L_`y'_`z' = total(L_jt) // number of workers per labor market --> necessary for computation of HHI + frequency weight
			bysort kldb10_`y'_imp nuts07_`z' year: egen W_`y'_`z' = total(W_jt) // total wage bill per labor market --> necessary for computation of HHI
			
			*bysort kldb10_`y'_imp nuts07_`z' year: egen h_`y'_`z' = total(h_jt) // number of hires per labor market --> necessary for computation of HHI
			*bysort kldb10_`y'_imp nuts07_`z' year: egen l_`y'_`z' = total(l_jt) // number of workers per labor market --> necessary for computation of HHI + frequency weight
			*bysort kldb10_`y'_imp nuts07_`z' year: egen w_`y'_`z' = total(w_jt) // total wage bill per labor market --> necessary for computation of HHI
			
			bysort kldb10_`y'_imp nuts07_`z' year: egen N_H_`y'_`z' = sum(H_jt>=1) // number of hiring establishments per labor market --> necessary for computation of INS
			bysort kldb10_`y'_imp nuts07_`z' year: egen N_L_`y'_`z' = sum(L_jt>=1) // number of employing establishments per labor market --> necessary for computation of INS + frequency weight
			bysort kldb10_`y'_imp nuts07_`z' year: egen N_W_`y'_`z' = sum(W_jt>=0) // number of paying establishments per labor market --> necessary for computation of INS

			*bysort kldb10_`y'_imp nuts07_`z' year: egen N_h_`y'_`z' = sum(h_jt>=1) // number of hiring establishments per labor market --> necessary for computation of INS
			*bysort kldb10_`y'_imp nuts07_`z' year: egen N_l_`y'_`z' = sum(l_jt>=1) // number of employing establishments per labor market --> necessary for computation of INS + frequency weight
			*bysort kldb10_`y'_imp nuts07_`z' year: egen N_w_`y'_`z' = sum(w_jt>=0) // number of paying establishments per labor market --> necessary for computation of INS
			
			
			gen s_H_`y'_`z'_jt = H_jt / H_`y'_`z'
			gen s_L_`y'_`z'_jt = L_jt / L_`y'_`z'
			gen s_W_`y'_`z'_jt = W_jt / W_`y'_`z'
			
			*gen s_h_`y'_`z'_jt = h_jt / h_`y'_`z'
			*gen s_l_`y'_`z'_jt = l_jt / l_`y'_`z'
			*gen s_w_`y'_`z'_jt = w_jt / w_`y'_`z'			


			count if s_H_`y'_`z'_jt==0
			count if s_L_`y'_`z'_jt==0
			count if s_W_`y'_`z'_jt==0
			
			*count if s_h_`y'_`z'_jt==0
			*count if s_l_`y'_`z'_jt==0
			*count if s_w_`y'_`z'_jt==0

			*drop L_jt H_jt W_jt l_jt h_jt w_jt
			


			foreach x of local flow {

				
				*** HERFINDAHL-HIRSCHMAN INDEX


				gen s_j_2 = (s_`x'_`y'_`z'_jt)^2

				bysort kldb10_`y'_imp nuts07_`z' year: egen HHI_`x'_`y'_`z' = total(s_j_2)
				replace HHI_`x'_`y'_`z' = . if HHI_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for markets and hiring concepts with zero hires

				drop s_j_2 // s_`x'_`y'_`z'_jt


				
				
				*** INVERSE NUMBER OF FIRMS (SUBJECTS)

				
				gen INS_`x'_`y'_`z' = 1 / N_`x'_`y'_`z'
				
				
				
				
				
				*** 1-FIRM, 3-FIRM, 4-FIRM, 5-FIRM, 6-FIRM, AND 8-FIRM CONCENTRATION RATIO 
				
				
				gsort kldb10_`y'_imp nuts07_`z' year -s_`x'_`y'_`z'_jt
				by kldb10_`y'_imp nuts07_`z' year: gen j = _n
				sort kldb10_`y'_imp nuts07_`z' year j

				gen s1_jt = 0
				replace s1_jt = s_`x'_`y'_`z'_jt if j<=1 
				by kldb10_`y'_imp nuts07_`z' year: egen CR1_`x'_`y'_`z' = total(s1_jt)
				replace CR1_`x'_`y'_`z' = . if CR1_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)

				gen s3_jt = 0
				replace s3_jt = s_`x'_`y'_`z'_jt if j<=3 
				by kldb10_`y'_imp nuts07_`z' year: egen CR3_`x'_`y'_`z' = total(s3_jt)
				replace CR3_`x'_`y'_`z' = . if CR3_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
				
				gen s4_jt = 0
				replace s4_jt = s_`x'_`y'_`z'_jt if j<=4 
				by kldb10_`y'_imp nuts07_`z' year: egen CR4_`x'_`y'_`z' = total(s4_jt)
				replace CR4_`x'_`y'_`z' = . if CR4_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
	
				gen s5_jt = 0
				replace s5_jt = s_`x'_`y'_`z'_jt if j<=5 
				by kldb10_`y'_imp nuts07_`z' year: egen CR5_`x'_`y'_`z' = total(s5_jt)
				replace CR5_`x'_`y'_`z' = . if CR5_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
		
				gen s6_jt = 0
				replace s6_jt = s_`x'_`y'_`z'_jt if j<=6 
				by kldb10_`y'_imp nuts07_`z' year: egen CR6_`x'_`y'_`z' = total(s6_jt)
				replace CR6_`x'_`y'_`z' = . if CR6_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
	
				gen s8_jt = 0
				replace s8_jt = s_`x'_`y'_`z'_jt if j<=8
				by kldb10_`y'_imp nuts07_`z' year: egen CR8_`x'_`y'_`z' = total(s8_jt)
				replace CR8_`x'_`y'_`z' = . if CR8_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
					
				drop j s_`x'_`y'_`z'_jt s1_jt s3_jt s4_jt s5_jt s6_jt s8_jt


				
				
				
					
			}
			
			*collapse information on concentration measures
			
			sort kldb10_`y'_imp nuts07_`z' year
			collapse (first) HHI_H_`y'_`z' INS_H_`y'_`z' CR1_H_`y'_`z' CR3_H_`y'_`z' CR4_H_`y'_`z' CR5_H_`y'_`z' CR6_H_`y'_`z' CR8_H_`y'_`z' ///
							 HHI_L_`y'_`z' INS_L_`y'_`z' CR1_L_`y'_`z' CR3_L_`y'_`z' CR4_L_`y'_`z' CR5_L_`y'_`z' CR6_L_`y'_`z' CR8_L_`y'_`z' ///
							 HHI_W_`y'_`z' INS_W_`y'_`z' CR1_W_`y'_`z' CR3_W_`y'_`z' CR4_W_`y'_`z' CR5_W_`y'_`z' CR6_W_`y'_`z' CR8_W_`y'_`z' ///
							 /// HHI_h_`y'_`z' INS_h_`y'_`z' CR1_h_`y'_`z' CR3_h_`y'_`z' CR4_h_`y'_`z' CR5_h_`y'_`z' CR6_h_`y'_`z' CR8_h_`y'_`z' 
							 /// HHI_l_`y'_`z' INS_l_`y'_`z' CR1_l_`y'_`z' CR3_l_`y'_`z' CR4_l_`y'_`z' CR5_l_`y'_`z' CR6_l_`y'_`z' CR8_l_`y'_`z' 
							 /// HHI_w_`y'_`z' INS_w_`y'_`z' CR1_w_`y'_`z' CR3_w_`y'_`z' CR4_w_`y'_`z' CR5_w_`y'_`z' CR6_w_`y'_`z' CR8_w_`y'_`z' 
							 H_`y'_`z' L_`y'_`z' W_`y'_`z' N_H_`y'_`z' N_L_`y'_`z' N_W_`y'_`z'   ///
							 /// h_`y'_`z' l_`y'_`z' w_`y'_`z' N_h_`y'_`z' N_l_`y'_`z' N_w_`y'_`z' 
							 , by(kldb10_`y'_imp nuts07_`z' year)
			
			order kldb10_`y'_imp nuts07_`z' year
			sort kldb10_`y'_imp nuts07_`z' year
			


			save "$data\LMC_kldb_`y'_`z'_1223_V1.dta", replace
				
			
			
			*create table with all X-digit occupation classifications

			keep kldb10_`y'_imp 
			duplicates drop

			sort kldb10_`y'_imp 

			save "$data\kldb10_`y'.dta", replace 


			*create dataset with an observation for each region-year combination and fill with information from dataset

			use "$data\LMC_kldb_`y'_`z'_1223_V1.dta", clear
					

			keep kldb10_`y'_imp nuts07_`z' 
			duplicates drop

			xtset nuts07_`z' kldb10_`y'_imp   // order matters

			cap xtdescribe
			tsfill, full // fill missing kldb10_`y'_imp observations

			xtset, clear


			*delete non-existent occupation classifications (that were mistakenly created by "tsfill" command)

			merge m:1 kldb10_`y'_imp using "$data\kldb10_`y'.dta"

			sort kldb10_`y'_imp nuts07_`z' 
			drop if _merge==1  // Y regions * Z industries  = YZ labor markets
			drop _merge


			*add year variable

			expand 12 // 12 years (2012-2023)

			sort kldb10_`y'_imp nuts07_`z' 

			by kldb10_`y'_imp nuts07_`z' : gen year = _n + 2011  // Y regions * Z industries * T years = YZT observations


			*merge initial information 


			merge 1:1 kldb10_`y'_imp nuts07_`z' year using "$data\LMC_kldb_`y'_`z'_1223_V1.dta"
					

			sort kldb10_`y'_imp nuts07_`z' year


			foreach x of local flow {

				replace HHI_`x'_`y'_`z' = . if _merge==1
				replace INS_`x'_`y'_`z' = . if _merge==1
				replace CR1_`x'_`y'_`z' = . if _merge==1
				replace CR3_`x'_`y'_`z' = . if _merge==1
				replace CR4_`x'_`y'_`z' = . if _merge==1
				replace CR5_`x'_`y'_`z' = . if _merge==1
				replace CR6_`x'_`y'_`z' = . if _merge==1
				replace CR8_`x'_`y'_`z' = . if _merge==1
				
				replace `x'_`y'_`z' = 0 if _merge==1
				replace N_`x'_`y'_`z' = 0 if _merge==1

			}


			drop _merge



			save "$data\LMC_kldb_`y'_`z'_1223_V2.dta", replace
					
				 

			*rename variables
			
			foreach x of local flow {
			
				label variable HHI_`x'_`y'_`z' "Herfindahl-Hirschman Index"
				label variable INS_`x'_`y'_`z' "Inverse Number of Firms"
				label variable CR1_`x'_`y'_`z' "1-Firm Concentration Ratio"
				label variable CR3_`x'_`y'_`z' "3-Firm Concentration Ratio"
				label variable CR4_`x'_`y'_`z' "4-Firm Concentration Ratio"
				label variable CR5_`x'_`y'_`z' "5-Firm Concentration Ratio"
				label variable CR6_`x'_`y'_`z' "6-Firm Concentration Ratio"
				label variable CR8_`x'_`y'_`z' "-Firm Concentration Ratio"

			}

			
			label variable H_`y'_`z' "Number of Hires"
			label variable L_`y'_`z' "Number of Workers"
			label variable W_`y'_`z' "Wage Bill"
			
			*label variable h_`y'_`z' "Number of Hires"
			*label variable l_`y'_`z' "Number of Workers"
			*label variable w_`y'_`z' "Wage Bill"
			
			
			label variable N_H_`y'_`z' "Number of Hiring Firms"
			label variable N_L_`y'_`z' "Number of (Employing) Firms"
			label variable N_W_`y'_`z' "Number of (Paying) Firms"
			
			*label variable N_h_`y'_`z' "Number of Hiring Firms"
			*label variable N_l_`y'_`z' "Number of (Employing) Firms"
			*label variable N_w_`y'_`z' "Number of (Paying) Firms"

			label variable year "Year"


			
			sort kldb10_`y'_imp nuts07_`z' year
			order kldb10_`y'_imp nuts07_`z' year HHI_* INS_* CR1_* CR3_* CR4_* CR5_* CR6_* CR8_* H_* L_* W_* N_H_* N_L_* N_W_*  // h_* l_* w_* N_h_* N_l_* N_w_*

			
			
			if `"`y'"'=="99" {
			
				label variable kldb10_99_imp "No Occupational Dimension" // 1x
			}
				
			
			
			else if `"`y'"'=="15" {
			
				label variable kldb10_15_imp "Detailed Occupational Area (KldB10-15)" // 39x
			}
				
			
			else if `"`y'"'=="25" {
			
				label variable kldb10_25_imp "Detailed Occupational Main Group (KldB10-25)" // 135x
			}
			
			
			else if `"`y'"'=="35" {
			
				label variable kldb10_35_imp "Detailed Occupational Group (KldB10-35)" // 436x
			}
			
			
			else if `"`y'"'=="45" {
			
				label variable kldb10_45_imp "Detailed Occupational Sub-Group (KldB10-45)" // 1300x
			}
			

			
			
			
			if `"`z'"'=="99" {
			
				label variable nuts07_99 "No Spatial Dimension" // 1x
				
			}			
			

			else if `"`z'"'=="0" {
			
				rename nuts07_0 ram
				label variable ram "Commuting Zone" // 141x
				
			}			
			
			
			else if `"`z'"'=="1" {
			
				label variable nuts07_1 "Federal State (NUTS07-1)" // 16x
				
			}
			
			
			
			else if `"`z'"'=="2" {
			
				label variable nuts07_2 "Government Region (NUTS07-2)" // 38x
				
			}
			
			

			
			else if `"`z'"'=="3" {
			
				label variable nuts07_3 "District (NUTS07-3)" // 400x
				
			}
			
			
			
			else if `"`z'"'=="4" {
		
				rename nuts07_4 lau17
				label variable lau17 "Municipality (LAU17)" // 10,785x

			
			}
			
			
			

			
		
				

			save "$data\LMC_kldb_`y'_`z'_1223_V3.dta", replace 

			
			erase "$data\LMC_kldb_`y'_`z'_1223_V1.dta"
			erase "$data\LMC_kldb_`y'_`z'_1223_V2.dta"
			
		}
	
	}

}





*** 1.3.3 DETERMINE RELEVANT LABOR MARKETS ***


use "$data\BeH_1123.dta", clear

gen kldb10_99_imp = 1 // always the same

rename kldb10_5_imp kldb10_45_imp
label variable kldb10_45_imp "Detailed Occupational Sub-Group (KldB10-45)"


keep prs_id year wz08_2_imp kldb10_99_imp kldb10_15_imp kldb10_25_imp kldb10_35_imp kldb10_45_imp
order prs_id year wz08_2_imp kldb10_99_imp kldb10_15_imp kldb10_25_imp kldb10_35_imp kldb10_45_imp




*define non-agricultural business sector

tab wz08_2_imp, m


gen nabs = ( (wz08_2_imp>=5 & wz08_2_imp<=82) | wz08_2_imp==90 | (wz08_2_imp>=92 & wz08_2_imp<=96) )  

label define nabs 0 "0 No" 1 "1 Yes"
label values nabs nabs

label variable nabs "Non-Agricultural Business Sector (No=0, Yes=1)"

tab nabs, m
tab wz08_2_imp nabs, m


save "$data\NABS_kldb_1223.dta", replace





local kldb 99 15 25 35 45


foreach y of local kldb {
	
	
	display "Identify Problematic Occupations: KldB10-`y'"

	use "$data\NABS_kldb_1223.dta", clear
	
	collapse (mean) nabs_share=nabs, by(kldb10_`y'_imp)
		
	label variable nabs_share "Share of Jobs in Non-Agricultural Business Sector"

	quietly hist nabs_share, width(0.01) start(0) title(`y'-Digit Occupations) 
	quietly graph export "$fig\Histogram_NABS_Share_`y'.png", replace
	

	global N = _N 
	
	sort nabs_share
	
	quietly save "$data\NABS_kldb_`y'_1223_V1.dta", replace


	
	gen military = 0
	cap replace military = 1 if inlist(kldb10_15_imp, 2, 3, 4)
	cap replace military = 1 if inlist(kldb10_25_imp, 12, 13, 14)
	cap replace military = 1 if inlist(kldb10_35_imp, 114, 123, 132, 142)
	cap replace military = 1 if inlist(kldb10_45_imp, 1104, 1203, 1302, 1402)

	
	label variable military "Military Occupation (0=No, 1=Yes)"
	
	quietly keep if ( nabs_share<=0.5 | military==1 )
	
	
	global n = _N 
	
	keep kldb10_`y'_imp nabs_share
	sort kldb10_`y'_imp
	
	noisily di "Delete the following $n out of $N occupations:"
	
	noisily list
	
	quietly save "$data\NABS_kldb_`y'_1223.dta", replace

	
	
}






*** 1.3.4 DELETE IRRELEVANT LABOR MARKETS ***


local kldb 99 15 25 35 45
local nuts 99 0 1 2 3 4 

local flow H L W // h l w


foreach y of local kldb {
	
	
	if `"`y'"'=="35"  { // for 35-digit occupations: calculate HHI for all types of regions
			
				local nuts 0 99 1 2 3 4 
			}
			

	if `"`y'"'=="99" | `"`y'"'=="15" | `"`y'"'=="25" | `"`y'"'=="45"  { // for other types of occupations: calculate HHI for baseline type of region (#0)
			
				local nuts 0 // 99 1 2 3 4 
			}
	
	
	
	
	
	foreach z of local nuts {

		display "Delete Irrelevant Labor Markets: KldB10-`y' x NUTS07-`z'"

	
		quietly {
			
			use "$data\LMC_kldb_`y'_`z'_1223_V3.dta", clear 

			merge m:1 kldb10_`y'_imp using "$data\NABS_kldb_`y'_1223.dta"
			

			gen main = (_merge==1)
			drop _merge nabs_share
			
			label define main 0 "0 No" 1 "1 Yes"
			label values main main
			
			label variable main "Sufficient IEB Coverage (0=No, 1=Yes)"
			
			tab main, m
			
			foreach x of local flow {
				
				replace HHI_`x'_`y'_`z' = . if main==0
				replace INS_`x'_`y'_`z' = . if main==0
				replace CR1_`x'_`y'_`z' = . if main==0
				replace CR3_`x'_`y'_`z' = . if main==0
				replace CR4_`x'_`y'_`z' = . if main==0
				replace CR5_`x'_`y'_`z' = . if main==0
				replace CR6_`x'_`y'_`z' = . if main==0				
				replace CR8_`x'_`y'_`z' = . if main==0
	
			}
			
			
			save "$data\LMC_kldb_`y'_`z'_1223.dta", replace 
			
			erase "$data\LMC_kldb_`y'_`z'_1223_V3.dta"

		}	
	}
	
}








*** 1.4 LABOR MARKET CONCENTRATION: INDUSTRIES ***


*** 1.4.1 PREPARE DATASET ***


*note: different X-digit WZ08 industries add up to each other, i.e. each 5-digit WZ industry belongs to exactly one 4-digit WZ industry --> 1:1 relationship, i.e. collapse command can be simultaneously executed for different digits of WZ industries
*note: different X-digit NACE/LAU regions add up to each other, i.e. each LAU region belongs to exactly one 3-digit NUTS region --> 1:1 relationship, i.e. collapse command can be simultaneously executed for different digits of NUTS regions



*create dataset with number of workers per industry-region-firm-year combination



use "$data\BeH_1123.dta", replace 



gen wz08_5_imp_miss = (wz08_5_imp==.)
tab year wz08_5_imp_miss, m nofreq row 
drop wz08_5_imp_miss

drop if wz08_5_imp==.



gen lau17_miss = (lau17==.)
tab year lau17_miss, m 
drop lau17_miss

drop if lau17==.




rename wz08_1c_imp wz08_1_imp
rename lau17 nuts07_4
rename ram nuts07_0


tab year, m

keep if year>=2012 // note: wz08 only available since 2012, inflows in 2011 cannot be measured (first year)
keep if year<=2023 // note: current edge of BeH data

drop if wz08_5_imp==. // not yet deleted above
drop if nuts07_4==.  // already deleted above
	
tab type, m

gen inflow_mini = inflow
replace inflow_mini = 0 if type==3

gen employment_mini = employment
replace employment_mini = 0 if type==3

gen wage_bill_imp_mini = wage_bill_imp
replace wage_bill_imp_mini = 0 if type==3

gen wz08_99_imp = 1 // always the same
gen nuts07_99 = 1 // always the same

collapse (sum) H_jt=inflow L_jt=employment W_jt=wage_bill_imp h_jt=inflow_mini l_jt=employment_mini w_jt=wage_bill_imp_mini ///
			   , by(betnr year wz08_99_imp wz08_1_imp wz08_2_imp wz08_3_imp wz08_4_imp wz08_5_imp nuts07_99 nuts07_0 nuts07_1 nuts07_2 nuts07_3 nuts07_4)

   
duplicates report betnr year // there are almost no duplicates --> reason: each establishment-year observation can employ only one industry; however: in this BeH version, in rare cases, some firms from different municipalities may have the same establishemt number --> treat them as different firms for consistency


by betnr year: gen n = _n
by betnr year: gen N = _N
br if N>1



save "$data\LMC_wz_1223_V0.dta", replace 


**# Bookmark #1


*** 1.4.2 CALCULATE LABOR MARKET CONCENTRATION ***




local wz 4 99 1 2 3 5
local nuts 0 99 1 2 3 4  

local flow H L W // h l w

foreach y of local wz {


	
	if `"`y'"'=="4"  { // for 4-digit industries: calculate HHI for all types of regions
			
				local nuts 0 99 1 2 3 4 
			}
			

	if `"`y'"'=="99" | `"`y'"'=="1" | `"`y'"'=="2" | `"`y'"'=="3"  | `"`y'"'=="5"  { // for other types of industries: calculate HHI for baseline type of region (#0)
			
				local nuts 0 // 99 1 2 3 4 
			}
	
	

	foreach z of local nuts {

		display "Calculate Labor Market Concentration: WZ08-`y' x NUTS07-`z'"
	
		quietly {

			use "$data\LMC_wz_1223_V0.dta", clear
			
			keep betnr year wz08_`y'_imp nuts07_`z' H_jt L_jt W_jt // h_jt l_jt w_jt 

			sort wz08_`y'_imp nuts07_`z' year betnr
			order wz08_`y'_imp nuts07_`z' year betnr H_jt L_jt W_jt // h_jt l_jt w_jt 
			
			
			bysort wz08_`y'_imp nuts07_`z' year: egen H_`y'_`z' = total(H_jt) // number of hires per labor market --> necessary for computation of HHI
			bysort wz08_`y'_imp nuts07_`z' year: egen L_`y'_`z' = total(L_jt) // number of workers per labor market --> necessary for computation of HHI + frequency weight
			bysort wz08_`y'_imp nuts07_`z' year: egen W_`y'_`z' = total(W_jt) // total wage bill per labor market --> necessary for computation of HHI
			
			*bysort wz08_`y'_imp nuts07_`z' year: egen h_`y'_`z' = total(h_jt) // number of hires per labor market --> necessary for computation of HHI
			*bysort wz08_`y'_imp nuts07_`z' year: egen l_`y'_`z' = total(l_jt) // number of workers per labor market --> necessary for computation of HHI + frequency weight
			*bysort wz08_`y'_imp nuts07_`z' year: egen w_`y'_`z' = total(w_jt) // total wage bill per labor market --> necessary for computation of HHI
			
			bysort wz08_`y'_imp nuts07_`z' year: egen N_H_`y'_`z' = sum(H_jt>=1) // number of hiring establishments per labor market --> necessary for computation of INS
			bysort wz08_`y'_imp nuts07_`z' year: egen N_L_`y'_`z' = sum(L_jt>=1) // number of employing establishments per labor market --> necessary for computation of INS + frequency weight
			bysort wz08_`y'_imp nuts07_`z' year: egen N_W_`y'_`z' = sum(W_jt>=0) // number of paying establishments per labor market --> necessary for computation of INS

			*bysort wz08_`y'_imp nuts07_`z' year: egen N_h_`y'_`z' = sum(h_jt>=1) // number of hiring establishments per labor market --> necessary for computation of INS
			*bysort wz08_`y'_imp nuts07_`z' year: egen N_l_`y'_`z' = sum(l_jt>=1) // number of employing establishments per labor market --> necessary for computation of INS + frequency weight
			*bysort wz08_`y'_imp nuts07_`z' year: egen N_w_`y'_`z' = sum(w_jt>=0) // number of paying establishments per labor market --> necessary for computation of INS
			
			
			gen s_H_`y'_`z'_jt = H_jt / H_`y'_`z'
			gen s_L_`y'_`z'_jt = L_jt / L_`y'_`z'
			gen s_W_`y'_`z'_jt = W_jt / W_`y'_`z'
			
			*gen s_h_`y'_`z'_jt = h_jt / h_`y'_`z'
			*gen s_l_`y'_`z'_jt = l_jt / l_`y'_`z'
			*gen s_w_`y'_`z'_jt = w_jt / w_`y'_`z'			


			count if s_H_`y'_`z'_jt==0
			count if s_L_`y'_`z'_jt==0
			count if s_W_`y'_`z'_jt==0
			
			*count if s_h_`y'_`z'_jt==0
			*count if s_l_`y'_`z'_jt==0
			*count if s_w_`y'_`z'_jt==0

			*drop L_jt H_jt W_jt l_jt h_jt w_jt
			


			foreach x of local flow {

				
				*** HERFINDAHL-HIRSCHMAN INDEX


				gen s_j_2 = (s_`x'_`y'_`z'_jt)^2

				bysort wz08_`y'_imp nuts07_`z' year: egen HHI_`x'_`y'_`z' = total(s_j_2)
				replace HHI_`x'_`y'_`z' = . if HHI_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for markets and hiring concepts with zero hires

				drop s_j_2 // s_`x'_`y'_`z'_jt


				
				
				*** INVERSE NUMBER OF FIRMS (SUBJECTS)

				
				gen INS_`x'_`y'_`z' = 1 / N_`x'_`y'_`z'
				
				
				
				
				
				*** 1-FIRM, 3-FIRM, 4-FIRM, 5-FIRM, 6-FIRM, AND 8-FIRM CONCENTRATION RATIO 
				
				
				gsort wz08_`y'_imp nuts07_`z' year -s_`x'_`y'_`z'_jt
				by wz08_`y'_imp nuts07_`z' year: gen j = _n
				sort wz08_`y'_imp nuts07_`z' year j

				gen s1_jt = 0
				replace s1_jt = s_`x'_`y'_`z'_jt if j<=1 
				by wz08_`y'_imp nuts07_`z' year: egen CR1_`x'_`y'_`z' = total(s1_jt)
				replace CR1_`x'_`y'_`z' = . if CR1_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)

				gen s3_jt = 0
				replace s3_jt = s_`x'_`y'_`z'_jt if j<=3 
				by wz08_`y'_imp nuts07_`z' year: egen CR3_`x'_`y'_`z' = total(s3_jt)
				replace CR3_`x'_`y'_`z' = . if CR3_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
				
				gen s4_jt = 0
				replace s4_jt = s_`x'_`y'_`z'_jt if j<=4 
				by wz08_`y'_imp nuts07_`z' year: egen CR4_`x'_`y'_`z' = total(s4_jt)
				replace CR4_`x'_`y'_`z' = . if CR4_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
	
				gen s5_jt = 0
				replace s5_jt = s_`x'_`y'_`z'_jt if j<=5 
				by wz08_`y'_imp nuts07_`z' year: egen CR5_`x'_`y'_`z' = total(s5_jt)
				replace CR5_`x'_`y'_`z' = . if CR5_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
		
				gen s6_jt = 0
				replace s6_jt = s_`x'_`y'_`z'_jt if j<=6 
				by wz08_`y'_imp nuts07_`z' year: egen CR6_`x'_`y'_`z' = total(s6_jt)
				replace CR6_`x'_`y'_`z' = . if CR6_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
	
				gen s8_jt = 0
				replace s8_jt = s_`x'_`y'_`z'_jt if j<=8
				by wz08_`y'_imp nuts07_`z' year: egen CR8_`x'_`y'_`z' = total(s8_jt)
				replace CR8_`x'_`y'_`z' = . if CR8_`x'_`y'_`z'==0 & s_`x'_`y'_`z'_jt==. // sum of missings = 0 --> only relevant for hires (=subset of dataset)
					
				drop j s_`x'_`y'_`z'_jt s1_jt s3_jt s4_jt s5_jt s6_jt s8_jt


				
				
				
					
			}
			
			*collapse information on concentration measures
			
			sort wz08_`y'_imp nuts07_`z' year
			collapse (first) HHI_H_`y'_`z' INS_H_`y'_`z' CR1_H_`y'_`z' CR3_H_`y'_`z' CR4_H_`y'_`z' CR5_H_`y'_`z' CR6_H_`y'_`z' CR8_H_`y'_`z' ///
							 HHI_L_`y'_`z' INS_L_`y'_`z' CR1_L_`y'_`z' CR3_L_`y'_`z' CR4_L_`y'_`z' CR5_L_`y'_`z' CR6_L_`y'_`z' CR8_L_`y'_`z' ///
							 HHI_W_`y'_`z' INS_W_`y'_`z' CR1_W_`y'_`z' CR3_W_`y'_`z' CR4_W_`y'_`z' CR5_W_`y'_`z' CR6_W_`y'_`z' CR8_W_`y'_`z' ///
							 /// HHI_h_`y'_`z' INS_h_`y'_`z' CR1_h_`y'_`z' CR3_h_`y'_`z' CR4_h_`y'_`z' CR5_h_`y'_`z' CR6_h_`y'_`z' CR8_h_`y'_`z' 
							 /// HHI_l_`y'_`z' INS_l_`y'_`z' CR1_l_`y'_`z' CR3_l_`y'_`z' CR4_l_`y'_`z' CR5_l_`y'_`z' CR6_l_`y'_`z' CR8_l_`y'_`z' 
							 /// HHI_w_`y'_`z' INS_w_`y'_`z' CR1_w_`y'_`z' CR3_w_`y'_`z' CR4_w_`y'_`z' CR5_w_`y'_`z' CR6_w_`y'_`z' CR8_w_`y'_`z' 
							 H_`y'_`z' L_`y'_`z' W_`y'_`z' N_H_`y'_`z' N_L_`y'_`z' N_W_`y'_`z'   ///
							 /// h_`y'_`z' l_`y'_`z' w_`y'_`z' N_h_`y'_`z' N_l_`y'_`z' N_w_`y'_`z' 
							 , by(wz08_`y'_imp nuts07_`z' year)
			
			order wz08_`y'_imp nuts07_`z' year
			sort wz08_`y'_imp nuts07_`z' year
			


			save "$data\LMC_wz_`y'_`z'_1223_V1.dta", replace
				
			
			
			*create table with all X-digit industry classifications

			keep wz08_`y'_imp 
			duplicates drop

			sort wz08_`y'_imp 

			save "$data\wz08_`y'.dta", replace 


			*create dataset with an observation for each region-year combination and fill with information from dataset

			use "$data\LMC_wz_`y'_`z'_1223_V1.dta", clear
					

			keep wz08_`y'_imp nuts07_`z' 
			duplicates drop

			xtset nuts07_`z' wz08_`y'_imp   // order matters

			cap xtdescribe
			tsfill, full // fill missing wz08_`y'_imp observations

			xtset, clear


			*delete non-existent industry classifications (that were mistakenly created by "tsfill" command)

			merge m:1 wz08_`y'_imp using "$data\wz08_`y'.dta"

			sort wz08_`y'_imp nuts07_`z' 
			drop if _merge==1  // Y regions * Z industries  = YZ labor markets
			drop _merge


			*add year variable

			expand 12 // 12 years (2012-2023)

			sort wz08_`y'_imp nuts07_`z' 

			by wz08_`y'_imp nuts07_`z' : gen year = _n + 2011  // Y regions * Z industries * T years = YZT observations


			*merge initial information 


			merge 1:1 wz08_`y'_imp nuts07_`z' year using "$data\LMC_wz_`y'_`z'_1223_V1.dta"
					

			sort wz08_`y'_imp nuts07_`z' year


			foreach x of local flow {

				replace HHI_`x'_`y'_`z' = . if _merge==1
				replace INS_`x'_`y'_`z' = . if _merge==1
				replace CR1_`x'_`y'_`z' = . if _merge==1
				replace CR3_`x'_`y'_`z' = . if _merge==1
				replace CR4_`x'_`y'_`z' = . if _merge==1
				replace CR5_`x'_`y'_`z' = . if _merge==1
				replace CR6_`x'_`y'_`z' = . if _merge==1
				replace CR8_`x'_`y'_`z' = . if _merge==1
				
				replace `x'_`y'_`z' = 0 if _merge==1
				replace N_`x'_`y'_`z' = 0 if _merge==1

			}


			drop _merge



			save "$data\LMC_wz_`y'_`z'_1223_V2.dta", replace
					
				 

			*rename variables
			
			foreach x of local flow {
			
				label variable HHI_`x'_`y'_`z' "Herfindahl-Hirschman Index"
				label variable INS_`x'_`y'_`z' "Inverse Number of Firms"
				label variable CR1_`x'_`y'_`z' "1-Firm Concentration Ratio"
				label variable CR3_`x'_`y'_`z' "3-Firm Concentration Ratio"
				label variable CR4_`x'_`y'_`z' "4-Firm Concentration Ratio"
				label variable CR5_`x'_`y'_`z' "5-Firm Concentration Ratio"
				label variable CR6_`x'_`y'_`z' "6-Firm Concentration Ratio"
				label variable CR8_`x'_`y'_`z' "-Firm Concentration Ratio"

			}

			
			label variable H_`y'_`z' "Number of Hires"
			label variable L_`y'_`z' "Number of Workers"
			label variable W_`y'_`z' "Wage Bill"
			
			*label variable h_`y'_`z' "Number of Hires"
			*label variable l_`y'_`z' "Number of Workers"
			*label variable w_`y'_`z' "Wage Bill"
			
			
			label variable N_H_`y'_`z' "Number of Hiring Firms"
			label variable N_L_`y'_`z' "Number of (Employing) Firms"
			label variable N_W_`y'_`z' "Number of (Paying) Firms"
			
			*label variable N_h_`y'_`z' "Number of Hiring Firms"
			*label variable N_l_`y'_`z' "Number of (Employing) Firms"
			*label variable N_w_`y'_`z' "Number of (Paying) Firms"

			label variable year "Year"


			
			sort wz08_`y'_imp nuts07_`z' year
			order wz08_`y'_imp nuts07_`z' year HHI_* INS_* CR1_* CR3_* CR4_* CR5_* CR6_* CR8_* H_* L_* W_* N_H_* N_L_* N_W_*  // h_* l_* w_* N_h_* N_l_* N_w_*

			
			
			if `"`y'"'=="99" {
			
				label variable wz08_99_imp "No Industrial Dimension" // 1x
			}
				
			
			
			else if `"`y'"'=="1" {
			
				label variable wz08_1_imp "Industrial Section (WZ08-1)" // 38x
			}
				
			
			else if `"`y'"'=="2" {
			
				label variable wz08_2_imp "Industrial Division (WZ08-2)" // 88x
			}
			
			
			else if `"`y'"'=="3" {
			
				label variable wz08_3_imp "Industrial Group (WZ08-3)" // 272x
			}
			
			
			else if `"`y'"'=="4" {
			
				label variable wz08_4_imp "Industrial Class (WZ08-4)" // 615x
			}
			
			
			else if `"`y'"'=="5" {
			
				label variable wz08_5_imp "Industrial Sub-Class (WZ08-5)" // 839x
			}
			
			
			
			
			if `"`z'"'=="99" {
			
				label variable nuts07_99 "No Spatial Dimension" // 1x
				
			}			
			

			else if `"`z'"'=="0" {
			
				rename nuts07_0 ram
				label variable ram "Commuting Zone" // 141x
				
			}			
			
			
			else if `"`z'"'=="1" {
			
				label variable nuts07_1 "Federal State (NUTS07-1)" // 16x
				
			}
			
			
			
			else if `"`z'"'=="2" {
			
				label variable nuts07_2 "Government Region (NUTS07-2)" // 38x
				
			}
			
			

			
			else if `"`z'"'=="3" {
			
				label variable nuts07_3 "District (NUTS07-3)" // 400x
				
			}
			
			
			
			else if `"`z'"'=="4" {
		
				rename nuts07_4 lau17
				label variable lau17 "Municipality (LAU17)" // 10,785x

			
			}
			
			
			

			
		
				

			save "$data\LMC_wz_`y'_`z'_1223_V3.dta", replace 

			
			erase "$data\LMC_wz_`y'_`z'_1223_V1.dta"
			erase "$data\LMC_wz_`y'_`z'_1223_V2.dta"
			
		}
	
	}

}





*** 1.4.3 DETERMINE RELEVANT LABOR MARKETS ***


use "$data\BeH_1123.dta", clear

gen wz08_99_imp = 1 // always the same

label variable wz08_5_imp "Industrial Sub-Class (WZ08-5)"

rename wz08_1c_imp wz08_1_imp

keep prs_id year wz08_2_imp wz08_99_imp wz08_1_imp wz08_3_imp wz08_4_imp wz08_5_imp
order prs_id year wz08_2_imp wz08_99_imp wz08_1_imp wz08_3_imp wz08_4_imp wz08_5_imp




*define non-agricultural business sector

tab wz08_2_imp, m


gen nabs = ( (wz08_2_imp>=5 & wz08_2_imp<=82) | wz08_2_imp==90 | (wz08_2_imp>=92 & wz08_2_imp<=96) )  

label define nabs 0 "0 No" 1 "1 Yes"
label values nabs nabs

label variable nabs "Non-Agricultural Business Sector (No=0, Yes=1)"

tab nabs, m
tab wz08_2_imp nabs, m


save "$data\NABS_wz_1223.dta", replace





local wz 99 1 2 3 4 5


foreach y of local wz {
	
	
	display "Identify Problematic Industries: WZ08-`y'"

	use "$data\NABS_wz_1223.dta", clear
	
	collapse (mean) nabs_share=nabs, by(wz08_`y'_imp)
		
	label variable nabs_share "Share of Jobs in Non-Agricultural Business Sector"

	quietly hist nabs_share, width(0.01) start(0) title(`y'-Digit Industries) 
	quietly graph export "$fig\Histogram_NABS_Share_`y'.png", replace
	

	global N = _N 
	
	sort nabs_share
	
	quietly save "$data\NABS_wz_`y'_1223_V1.dta", replace


	
	*gen military = 0
	*cap replace military = 1 if inlist(kldb10_15_imp, 2, 3, 4)
	*cap replace military = 1 if inlist(kldb10_25_imp, 12, 13, 14)
	*cap replace military = 1 if inlist(kldb10_35_imp, 114, 123, 132, 142)
	*cap replace military = 1 if inlist(kldb10_45_imp, 1104, 1203, 1302, 1402)

	
	*label variable military "Military Occupation (0=No, 1=Yes)"
	
	quietly keep if ( nabs_share<=0.5 ) // | military==1 )
	
	
	global n = _N 
	
	keep wz08_`y'_imp nabs_share
	sort wz08_`y'_imp
	
	noisily di "Delete the following $n out of $N industries:"
	
	noisily list
	
	quietly save "$data\NABS_wz_`y'_1223.dta", replace

	
	
}






*** 1.4.4 DELETE IRRELEVANT LABOR MARKETS ***


local wz 99 1 2 3 4 5
local nuts 99 0 1 2 3 4 

local flow H L W // h l w


foreach y of local wz {
	
	
	if `"`y'"'=="4"  { // for 4-digit industries: calculate HHI for all types of regions
			
				local nuts 0 99 1 2 3 4 
			}
			

	if `"`y'"'=="99" | `"`y'"'=="1" | `"`y'"'=="2" | `"`y'"'=="3" | `"`y'"'=="5" { // for other types of industries: calculate HHI for baseline type of region (#0)
			
				local nuts 0 // 99 1 2 3 4 
			}
	
	
	
	
	
	foreach z of local nuts {

		display "Delete Irrelevant Labor Markets: WZ08-`y' x NUTS07-`z'"

	
		quietly {
			
			use "$data\LMC_wz_`y'_`z'_1223_V3.dta", clear 

			merge m:1 wz08_`y'_imp using "$data\NABS_wz_`y'_1223.dta"
			

			gen main = (_merge==1)
			drop _merge nabs_share
			
			label define main 0 "0 No" 1 "1 Yes"
			label values main main
			
			label variable main "Sufficient IEB Coverage (0=No, 1=Yes)"
			
			tab main, m
			
			foreach x of local flow {
				
				replace HHI_`x'_`y'_`z' = . if main==0
				replace INS_`x'_`y'_`z' = . if main==0
				replace CR1_`x'_`y'_`z' = . if main==0
				replace CR3_`x'_`y'_`z' = . if main==0
				replace CR4_`x'_`y'_`z' = . if main==0
				replace CR5_`x'_`y'_`z' = . if main==0
				replace CR6_`x'_`y'_`z' = . if main==0				
				replace CR8_`x'_`y'_`z' = . if main==0
	
			}
			
			
			save "$data\LMC_wz_`y'_`z'_1223.dta", replace 
			
			erase "$data\LMC_wz_`y'_`z'_1223_V3.dta"

		}	
	}
	
}














