


*** 2. SELF-CONTAINMENT OF LABOR MARKETS ***


*** 2.1 OCCUPATIONS ***


use "$data\BeH_1123_V9.dta", replace 



tab type, m

*choose one alternative:

*keep if ( type==1 | type==6 ) // regular/other full-time employment
*keep if ( type==1 | type==2 | type==6 | type== 7 ) // regular/other employment
keep if ( type==1 | type==2 | type==3 | type==4 | type==5 | type==6 | type==7  | type==. ) // total employment




keep if inrange(year,2012,2023)


*delete multiple worker-firm spells within one year


keep if employment==1 // keep only most important spell within worker-firm-year triple (essentially: deletion of spells shorter than 30 days)



*delete multiple worker spells within one year


gsort prs_id year -wage_day_imp ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability 
by prs_id year: gen n = _n
tab n, m

keep if n==1 // keep spell with highest daily wage per person-year combination
drop n

duplicates report prs_id year




*bysort prs_id (year): gen n = _n
*bysort prs_id (year): gen N = _N


keep prs_id year betnr inflow kldb10_* nuts07_* lau17 ram wz08_5_imp
order prs_id year betnr inflow kldb10_* nuts07_* lau17 ram wz08_5_imp

rename kldb10_1c_imp kldb10_1_imp 
clonevar kldb10_45_imp = kldb10_5_imp
drop kldb10_1b_imp kldb10_1a_imp


rename *_imp *

drop if kldb10_5==.
drop if wz08_5==.
drop if nuts07_3==.
drop if lau17==.

rename ram nuts07_0
rename lau17 nuts07_4



tab year, m

save "$data\ATT_kldb_1223_V1.dta", replace 

rename kldb10_15 kldb10_15_next 
rename kldb10_25 kldb10_25_next 
rename kldb10_35 kldb10_35_next 
rename kldb10_45 kldb10_45_next 
rename kldb10_1 kldb10_1_next 
rename kldb10_2 kldb10_2_next 
rename kldb10_3 kldb10_3_next 
rename kldb10_4 kldb10_4_next
rename kldb10_5 kldb10_5_next 

rename nuts07_0 nuts07_0_next 
rename nuts07_1 nuts07_1_next 
rename nuts07_2 nuts07_2_next 
rename nuts07_3 nuts07_3_next 
rename nuts07_4 nuts07_4_next

rename inflow inflow_next

replace year = year - 1
tab year, m

save "$data\ATT_kldb_1223_V2.dta", replace 



use "$data\ATT_kldb_1223_V1.dta", replace 

merge 1:1 prs_id year using "$data\ATT_kldb_1223_V2.dta", keepusing (*_next inflow_next)

tab year _merge, m
keep if _merge==3 
drop _merge

tab year, m

gen kldb10_99 = 1 // always the same
gen kldb10_99_next = 1 // always the same

gen nuts07_99 = 1 // always the same
gen nuts07_99_next = 1 // always the same

local kldb 99 15 25 35 45 1 2 3 4 5 
local nuts 99 0 1 2 3 4 

foreach y of local kldb {

	foreach z of local nuts {

	
		di "Calculate Labor Market Attachment: KldB10-`y' x NUTS07-`z'"


		gen byte att_`y'_`z' = ( kldb10_`y'==kldb10_`y'_next & nuts07_`z'==nuts07_`z'_next )


	}

}

keep *_next year att_*

save "$data\ATT_kldb_1223_V3.dta", replace 




*calculate share of stayers (for employment)

use "$data\ATT_kldb_1223_V3.dta", replace 

collapse (mean) att_*

gen type = 0
order type

label define type 0 "0 Unconditional" 1 "1 Conditional on Switching Firm"
label values type type

label variable type "Type of Flow"

save "$data\ATT_kldb_1223_V4.dta", replace 




*calculate share of stayers (for inflows)


use "$data\ATT_kldb_1223_V3.dta", replace 


keep if inflow_next==1
collapse (mean) att_*

gen type = 1
order type


label define type 0 "0 Unconditional" 1 "1 Upon Switching Firm"
label values type type

label variable type "Type of Flow"

save "$data\ATT_kldb_1223_V5.dta", replace 




*prepare matrices

use "$data\ATT_kldb_1223_V4.dta", clear
append using "$data\ATT_kldb_1223_V5.dta"


*gen i = 1
*order i

reshape long att_99_ att_15_ att_25_ att_35_ att_45_ att_1_ att_2_ att_3_ att_4_ att_5_ , i(type) j(nuts)
*drop i

rename att_99 att
replace nuts = . if nuts==99

rename att_*_ att_*


order type nuts att att_15 att_25 att_35 att_45 att_1 att_2 att_3 att_3 att_4 att_5
rename att kldb
rename att_* kldb_*

gen nuts_str = ""

replace nuts_str = "Commuting Zone" if nuts==0
replace nuts_str = "Federal State" if nuts==1
replace nuts_str = "Government Region" if nuts==2
replace nuts_str = "District" if nuts==3
replace nuts_str = "Municipality" if nuts==4
replace nuts_str = "Country" if nuts==.

gen nuts_order = .
replace nuts_order = 4 if nuts==0
replace nuts_order = 2 if nuts==1
replace nuts_order = 3 if nuts==2
replace nuts_order = 5 if nuts==3
replace nuts_order = 6 if nuts==4
replace nuts_order = 1 if nuts==.

sort type nuts_order
order type nuts_str

drop nuts nuts_order
rename nuts_str nuts


foreach x of varlist kldb-kldb_5 {
	
	replace `x' = `x' * 100
	
}




save "$data\ATT_kldb_1223.dta", replace 









*Table 1

use "$data\ATT_kldb_1223.dta", clear


drop kldb_1 kldb_2 kldb_3 kldb_4 kldb_5
xpose, clear varname

format v* %5.1f

rename _varname kldb
order kldb

drop if _n==2

rename v1 nuts_99
rename v2 nuts_1
rename v3 nuts_2
rename v4 nuts_0
rename v5 nuts_3
rename v6 nuts_4

rename v7  nuts_99_hire
rename v8  nuts_1_hire
rename v9  nuts_2_hire
rename v10 nuts_0_hire
rename v11 nuts_3_hire
rename v12 nuts_4_hire

drop if _n==1


local kldb 1 2 3 4 5
local nuts 99 0 1 2 3 4 

foreach y of local kldb {
	
	foreach z of local nuts {
		
	local att_`y'_`z' : di %4.1f nuts_`z'[`y']	
	local att_`y'_`z'_hire : di %4.1f nuts_`z'_hire[`y']	
		
	di "`att_`y'_`z''"
	di "`att_`y'_`z'_hire'"
	
		
	}
	
	
}





	

file open table_1 using "$file\Table 1.tex", write replace
		



	file write table_1 "\begin{table}[!ht]" _n
	file write table_1 "\centering" _n
	file write table_1 "%\resizebox{\textwidth}{!}{" _n
	file write table_1 "\scalebox{0.90}{" _n
	file write table_1 "\begin{threeparttable}" _n
	file write table_1 "\caption{Self-Containment of Labor Markets Defined By Occupations}" _n
	file write table_1 "\label{tab:1}" _n

	file write table_1 "\begin{tabular}{L{5cm}C{3cm}C{3cm}C{3cm}C{3cm}C{3cm}C{3cm}} \hline" _n
	file write table_1 "&&&&&& \\[-0.3cm]" _n

	file write table_1 "\multirow{4}{*}{\diagbox[height=4.4175\line, innerwidth=5cm]{\shortstack{Occupational \\ Delineation}}{\shortstack{ \\ \hspace{0.1cm}Spatial \\ Delineation}}}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\vphantom{/} \\ \textbf{None}\vphantom{/} \vphantom{/} \\ \vphantom{/} \\ \vphantom{/}  }}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\textbf{16}\vphantom{/} \\ \textbf{Federal}\vphantom{/} \\ \textbf{States}\vphantom{/} \\ NUTS-1\vphantom{/}  }}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\textbf{38}\vphantom{/} \\ \textbf{Government}\vphantom{/} \\ \textbf{Regions}\vphantom{/} \\ NUTS-2\vphantom{/}  }}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\textbf{141}\vphantom{/} \\ \textbf{Commuting}\vphantom{/} \\ \textbf{Zones}\vphantom{/} \\ \vphantom{/} \ }}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\textbf{400}\vphantom{/} \\ \textbf{Districts}\vphantom{/} \\ \vphantom{/} \\ NUTS-3\vphantom{/}  }}" _n

	file write table_1 "& \multirow{4.4}{*}{\shortstack{\textbf{10,785}\vphantom{/} \\ \textbf{Munici-}\vphantom{/} \\ \textbf{palities}\vphantom{/} \\ LAU\vphantom{/}  }} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[-0.1cm] \hline" _n

	file write table_1 "\multirow{3.4}{*}{\shortstack[l]{\vphantom{/} \\ \textbf{None}\vphantom{/} \\ \vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_1_99' \\ (`att_1_99_hire') \\ {[1]}}} & \multirow{3.4}{*}{\shortstack{`att_1_1' \\ (`att_1_1_hire') \\ {[16]}}} & \multirow{3.4}{*}{\shortstack{`att_1_2' \\ (`att_1_2_hire') \\ {[38]}}} & \multirow{3.4}{*}{\shortstack{`att_1_0' \\ (`att_1_0_hire') \\ {[141]}}} & \multirow{3.4}{*}{\shortstack{`att_1_3' \\ (`att_1_3_hire') \\ {[400]}}} & \multirow{3.4}{*}{\shortstack{`att_1_4' \\ (`att_1_4_hire') \\ {[10,785]}}} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[0.3cm]" _n

	file write table_1 "\multirow{3.4}{*}{\shortstack[l]{\textbf{39 Detailed}\vphantom{/} \\ \textbf{Occupational Areas}\vphantom{/} \\ 1-Digit KldB-10 $\times$ Level\vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_2_99' \\ (`att_2_99_hire') \\ {[39]}}} & \multirow{3.4}{*}{\shortstack{`att_2_1' \\ (`att_2_1_hire') \\ {[624]}}} & \multirow{3.4}{*}{\shortstack{`att_2_2' \\ (`att_2_2_hire') \\ {[1,482]}}} & \multirow{3.4}{*}{\shortstack{`att_2_0' \\ (`att_2_0_hire') \\ {[5,499]}}} & \multirow{3.4}{*}{\shortstack{`att_2_3' \\ (`att_2_3_hire') \\ {[15,600]}}} & \multirow{3.4}{*}{\shortstack{`att_2_4' \\ (`att_2_4_hire') \\ {[420,615]}}} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[0.3cm]" _n

	file write table_1 "\multirow{3.4}{*}{\shortstack[l]{\textbf{135 Detailed}\vphantom{/} \\ \textbf{Occupational Main Groups}\vphantom{/} \\ 2-Digit KldB-10 $\times$ Level\vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_3_99' \\ (`att_3_99_hire') \\ {[135]}}} & \multirow{3.4}{*}{\shortstack{`att_3_1' \\ (`att_3_1_hire') \\ {[2,160]}}} & \multirow{3.4}{*}{\shortstack{`att_3_2' \\ (`att_3_2_hire') \\ {[5,130]}}} & \multirow{3.4}{*}{\shortstack{`att_3_0' \\ (`att_3_0_hire') \\ {[19,035]}}} & \multirow{3.4}{*}{\shortstack{`att_3_3' \\ (`att_3_3_hire') \\ {[54,000]}}} & \multirow{3.4}{*}{\shortstack{`att_3_4' \\ (`att_3_4_hire') \\ {[1,455,975]}}} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[0.3cm]" _n

	file write table_1 "\multirow{3.4}{*}{\shortstack[l]{\textbf{436 Detailed}\vphantom{/} \\ \textbf{Occupational Groups}\vphantom{/} \\ 3-Digit KldB-10 $\times$ Level\vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_4_99' \\ (`att_4_99_hire') \\ {[436]}}} & \multirow{3.4}{*}{\shortstack{`att_4_1' \\ (`att_4_1_hire') \\ {[6,976]}}} & \multirow{3.4}{*}{\shortstack{`att_4_2' \\ (`att_4_2_hire') \\ {[16,568]}}} & \multirow{3.4}{*}{\shortstack{`att_4_0' \\ (`att_4_0_hire') \\ {[61,476]}}} & \multirow{3.4}{*}{\shortstack{`att_4_3' \\ (`att_4_3_hire') \\ {[174,400]}}} & \multirow{3.4}{*}{\shortstack{`att_4_4' \\ (`att_4_4_hire') \\ {[4,702,260]}}} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[0.3cm]" _n

	file write table_1 "\multirow{3.4}{*}{\shortstack[l]{\textbf{1,300 Detailed}\vphantom{/} \\ \textbf{Occupational Sub-Groups}\vphantom{/} \\ 4-Digit KldB-10 $\times$ Level\vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_5_99' \\ (`att_5_99_hire') \\ {[1,300]}}} & \multirow{3.4}{*}{\shortstack{`att_5_1' \\ (`att_5_1_hire') \\ {[20,800]}}} & \multirow{3.4}{*}{\shortstack{`att_5_2' \\ (`att_5_2_hire') \\ {[49,400]}}} & \multirow{3.4}{*}{\shortstack{`att_5_0' \\ (`att_5_0_hire') \\ {[183,300]}}} & \multirow{3.4}{*}{\shortstack{`att_5_3' \\ (`att_5_3_hire') \\ {[520,000]}}} & \multirow{3.4}{*}{\shortstack{`att_5_4' \\ (`att_5_4_hire') \\ {[14,020,500]}}} \\" _n
	file write table_1 "&&&&&& \\" _n
	file write table_1 "&&&&&& \\[0.3cm] \hline" _n
	file write table_1 "\end{tabular}" _n
	file write table_1 "\begin{tablenotes}[para]" _n
	file write table_1 "\footnotesize\textsc{Note. ---} The table displays the self-containment of differently segmented labor markets. Labor markets are pair-wise combinations of occupations and regions. The first value in each cell denotes the probability (in percent) that a worker in a certain labor market and year was already employed in the very same labor market in the year before. The second value in each cell (in parentheses) denotes the probability (in percent) that a newly hired worker in a certain labor market and year was already employed in the very same labor market in the year before (i.e., the probability is conditioned on workers who switch firms). The third value in each cell (in brackets) denotes the potential number of labor markets for the specific delineation. Note that the effective number of labor markets is generally lower because certain combinations of occupation and region may feature zero workers or hires. The yearly transition probabilities are calculated for workers' who are employed in adjacent years and refer to their main job which is the job (with a length of at least 30 days) that earns the highest daily wage in the respective calendar year. KldB = German Classification of Occupations. LAU = Local Administrative Unit. NUTS = Statistical Nomenclature of Territorial Units. Source: BEH, 2012-2023." _n
	file write table_1 "\end{tablenotes}" _n
	file write table_1 "\end{threeparttable}" _n
	file write table_1 "}" _n
	file write table_1 "\end{table}" _n


file close table_1






*** 2.2 INDUSTRIES ***




use "$data\BEH_1123_V9.dta", replace 



tab type, m

*choose one alternative:

*keep if ( type==1 | type==6 ) // regular/other full-time employment
*keep if ( type==1 | type==2 | type==6 | type== 7 ) // regular/other employment
keep if ( type==1 | type==2 | type==3 | type==4 | type==5 | type==6 | type==7  | type==. ) // total employment




keep if inrange(year,2012,2023)


*delete multiple worker-firm spells within one year


keep if employment==1 // keep only most important spell within worker-firm-year triple (essentially: deletion of spells shorter than 30 days)



*delete multiple worker spells within one year


gsort prs_id year -wage_day_imp ieb_fall_id // ensure stable sorting with "ieb_fall_id" for reproducability 
by prs_id year: gen n = _n
tab n, m

keep if n==1 // keep spell with highest daily wage per person-year combination
drop n

duplicates report prs_id year




*bysort prs_id (year): gen n = _n
*bysort prs_id (year): gen N = _N


keep prs_id year betnr inflow wz08_* nuts07_* lau17 ram kldb10_5_imp
order prs_id year betnr inflow wz08_* nuts07_* lau17 ram kldb10_5_imp

rename wz08_1c_imp wz08_1_imp
drop wz08_1b_imp wz08_1a_imp


rename *_imp *


drop if kldb10_5==.
drop if wz08_5==.
drop if nuts07_3==.
drop if lau17==.


rename ram nuts07_0
rename lau17 nuts07_4



tab year, m

save "$data\ATT_wz_1223_V1.dta", replace 

use "$data\ATT_wz_1223_V1.dta", clear


rename wz08_1 wz08_1_next 
rename wz08_2 wz08_2_next 
rename wz08_3 wz08_3_next 
rename wz08_4 wz08_4_next
rename wz08_5 wz08_5_next 

rename nuts07_0 nuts07_0_next 
rename nuts07_1 nuts07_1_next 
rename nuts07_2 nuts07_2_next 
rename nuts07_3 nuts07_3_next 
rename nuts07_4 nuts07_4_next

rename inflow inflow_next

replace year = year - 1
tab year, m

save "$data\ATT_wz_1223_V2.dta", replace 



use "$data\ATT_wz_1223_V1.dta", replace 

merge 1:1 prs_id year using "$data\ATT_wz_1223_V2.dta", keepusing (*_next inflow_next)

tab year _merge, m
keep if _merge==3 
drop _merge

tab year, m

gen wz08_99 = 1 // always the same
gen wz08_99_next = 1 // always the same

gen nuts07_99 = 1 // always the same
gen nuts07_99_next = 1 // always the same

local wz 99 1 2 3 4 5 
local nuts 99 0 1 2 3 4 

foreach y of local wz {

	foreach z of local nuts {

	
		di "Calculate Labor Market Attachment: WZ08-`y' x NUTS07-`z'"


		gen byte att_`y'_`z' = ( wz08_`y'==wz08_`y'_next & nuts07_`z'==nuts07_`z'_next )


	}

}

keep *_next year att_*

save "$data\ATT_wz_1223_V3.dta", replace 




*calculate share of stayers (for employment)

use "$data\ATT_wz_1223_V3.dta", replace 

collapse (mean) att_*

gen type = 0
order type

label define type 0 "0 Unconditional" 1 "1 Conditional on Switching Firm"
label values type type

label variable type "Type of Flow"

save "$data\ATT_wz_1223_V4.dta", replace 




*calculate share of stayers (for inflows)


use "$data\ATT_wz_1223_V3.dta", replace 


keep if inflow_next==1
collapse (mean) att_*

gen type = 1
order type


label define type 0 "0 Unconditional" 1 "1 Upon Switching Firm"
label values type type

label variable type "Type of Flow"

save "$data\ATT_wz_1223_V5.dta", replace 




*prepare matrices

use "$data\ATT_wz_1223_V4.dta", clear
append using "$data\ATT_wz_1223_V5.dta"


*gen i = 1
*order i

reshape long att_99_ att_1_ att_2_ att_3_ att_4_ att_5_ , i(type) j(nuts)
*drop i

rename att_99 att
replace nuts = . if nuts==99

rename att_*_ att_*


order type nuts att att_1 att_2 att_3 att_4 att_5
rename att wz
rename att_* wz_*

gen nuts_str = ""

replace nuts_str = "Commuting Zone" if nuts==0
replace nuts_str = "Federal State" if nuts==1
replace nuts_str = "Government Region" if nuts==2
replace nuts_str = "District" if nuts==3
replace nuts_str = "Municipality" if nuts==4
replace nuts_str = "Country" if nuts==.

gen nuts_order = .
replace nuts_order = 4 if nuts==0
replace nuts_order = 2 if nuts==1
replace nuts_order = 3 if nuts==2
replace nuts_order = 5 if nuts==3
replace nuts_order = 6 if nuts==4
replace nuts_order = 1 if nuts==.

sort type nuts_order
order type nuts_str

drop nuts nuts_order
rename nuts_str nuts


foreach x of varlist wz-wz_5 {
	
	replace `x' = `x' * 100
	
}




save "$data\ATT_wz_1223.dta", replace 









*Table 2

use "$data\ATT_wz_1223.dta", clear


xpose, clear varname

format v* %5.1f

rename _varname wz
order wz

drop if _n==2

rename v1 nuts_99
rename v2 nuts_1
rename v3 nuts_2
rename v4 nuts_0
rename v5 nuts_3
rename v6 nuts_4

rename v7  nuts_99_hire
rename v8  nuts_1_hire
rename v9  nuts_2_hire
rename v10 nuts_0_hire
rename v11 nuts_3_hire
rename v12 nuts_4_hire

drop if _n==1


local wz 1 2 3 4 5 6
local nuts 99 0 1 2 3 4 

foreach y of local wz {
	
	foreach z of local nuts {
		
	local att_`y'_`z' : di %4.1f nuts_`z'[`y']	
	local att_`y'_`z'_hire : di %4.1f nuts_`z'_hire[`y']	
		
	di "`att_`y'_`z''"
	di "`att_`y'_`z'_hire'"
	
		
	}
	
	
}





	

file open table_2 using "$file\Table 2.tex", write replace
		



	file write table_2 "\begin{table}[!ht]" _n
	file write table_2 "\centering" _n
	file write table_2 "%\resizebox{\textwidth}{!}{" _n
	file write table_2 "\scalebox{0.90}{" _n
	file write table_2 "\begin{threeparttable}" _n
	file write table_2 "\caption{Self-Containment of Labor Markets Defined By Industries}" _n
	file write table_2 "\label{tab:2}" _n

	file write table_2 "\begin{tabular}{L{5cm}C{3cm}C{3cm}C{3cm}C{3cm}C{3cm}C{3cm}} \hline" _n
	file write table_2 "&&&&&& \\[-0.3cm]" _n

	file write table_2 "\multirow{4}{*}{\diagbox[height=4.4175\line, innerwidth=5cm]{\shortstack{Industrial \\ Delineation}}{\shortstack{ \\ \hspace{0.1cm}Spatial \\ Delineation}}}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\vphantom{/} \\ \textbf{None}\vphantom{/} \vphantom{/} \\ \vphantom{/} \\ \vphantom{/}  }}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\textbf{16}\vphantom{/} \\ \textbf{Federal}\vphantom{/} \\ \textbf{States}\vphantom{/} \\ NUTS-1\vphantom{/} }}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\textbf{38}\vphantom{/} \\ \textbf{Government}\vphantom{/} \\ \textbf{Regions}\vphantom{/} \\ NUTS-2\vphantom{/}  }}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\textbf{141}\vphantom{/} \\ \textbf{Commuting}\vphantom{/} \\ \textbf{Zones}\vphantom{/} \\ \vphantom{/}  }}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\textbf{400}\vphantom{/} \\ \textbf{Districts}\vphantom{/} \\ \vphantom{/} \\ NUTS-3\vphantom{/} }}" _n

	file write table_2 "& \multirow{4.4}{*}{\shortstack{\textbf{10,785}\vphantom{/} \\ \textbf{Munici-}\vphantom{/} \\ \textbf{palities}\vphantom{/} \\ LAU\vphantom{/}  }} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[-0.1cm] \hline" _n

	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\vphantom{/} \\ \textbf{None}\vphantom{/} \\ \vphantom{/}}} & \multirow{3.4}{*}{\shortstack{`att_1_99' \\ (`att_1_99_hire') \\ {[1]}}} & \multirow{3.4}{*}{\shortstack{`att_1_1' \\ (`att_1_1_hire') \\ {[16]}}} & \multirow{3.4}{*}{\shortstack{`att_1_2' \\ (`att_1_2_hire') \\ {[38]}}} & \multirow{3.4}{*}{\shortstack{`att_1_0' \\ (`att_1_0_hire') \\ {[141]}}} & \multirow{3.4}{*}{\shortstack{`att_1_3' \\ (`att_1_3_hire') \\ {[400]}}} & \multirow{3.4}{*}{\shortstack{`att_1_4' \\ (`att_1_4_hire') \\ {[10,785]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm]" _n

	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\textbf{38}\vphantom{/} \\ \textbf{Industrial Sections}\vphantom{/} \\ 1-Digit WZ-08}} & \multirow{3.4}{*}{\shortstack{`att_2_99' \\ (`att_2_99_hire') \\ {[38]}}} & \multirow{3.4}{*}{\shortstack{`att_2_1' \\ (`att_2_1_hire') \\ {[608]}}} & \multirow{3.4}{*}{\shortstack{`att_2_2' \\ (`att_2_2_hire') \\ {[1,444]}}} & \multirow{3.4}{*}{\shortstack{`att_2_0' \\ (`att_2_0_hire') \\ {[5,358]}}} & \multirow{3.4}{*}{\shortstack{`att_2_3' \\ (`att_2_3_hire') \\ {[15,200]}}} & \multirow{3.4}{*}{\shortstack{`att_2_4' \\ (`att_2_4_hire') \\ {[409,830]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm]" _n

	
	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\textbf{88}\vphantom{/} \\ \textbf{Industrial Divisions}\vphantom{/} \\ 2-Digit WZ-08}} & \multirow{3.4}{*}{\shortstack{`att_3_99' \\ (`att_3_99_hire') \\ {[88]}}} & \multirow{3.4}{*}{\shortstack{`att_3_1' \\ (`att_3_1_hire') \\ {[1,408]}}} & \multirow{3.4}{*}{\shortstack{`att_3_2' \\ (`att_3_2_hire') \\ {[3,344]}}} & \multirow{3.4}{*}{\shortstack{`att_3_0' \\ (`att_3_0_hire') \\ {[12,408]}}} & \multirow{3.4}{*}{\shortstack{`att_3_3' \\ (`att_3_3_hire') \\ {[35,200]}}} & \multirow{3.4}{*}{\shortstack{`att_3_4' \\ (`att_3_4_hire') \\ {[949,080]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm]" _n

	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\textbf{272}\vphantom{/} \\ \textbf{Industrial Groups}\vphantom{/} \\ 3-Digit WZ-08}} & \multirow{3.4}{*}{\shortstack{`att_4_99' \\ (`att_4_99_hire') \\ {[272]}}} & \multirow{3.4}{*}{\shortstack{`att_3_1' \\ (`att_3_1_hire') \\ {[4,352]}}} & \multirow{3.4}{*}{\shortstack{`att_4_2' \\ (`att_4_2_hire') \\ {[10,336]}}} & \multirow{3.4}{*}{\shortstack{`att_4_0' \\ (`att_4_0_hire') \\ {[38,352]}}} & \multirow{3.4}{*}{\shortstack{`att_4_3' \\ (`att_4_3_hire') \\ {[108,800]}}} & \multirow{3.4}{*}{\shortstack{`att_4_4' \\ (`att_4_4_hire') \\ {[2,933,520]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm]" _n

	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\textbf{615}\vphantom{/} \\ \textbf{Industrial Classes}\vphantom{/} \\ 4-Digit WZ-08}} & \multirow{3.4}{*}{\shortstack{`att_5_99' \\ (`att_5_99_hire') \\ {[615]}}} & \multirow{3.4}{*}{\shortstack{`att_4_1' \\ (`att_4_1_hire') \\ {[9,840]}}} & \multirow{3.4}{*}{\shortstack{`att_5_2' \\ (`att_5_2_hire') \\ {[23,370]}}} & \multirow{3.4}{*}{\shortstack{`att_5_0' \\ (`att_5_0_hire') \\ {[86,715]}}} & \multirow{3.4}{*}{\shortstack{`att_5_3' \\ (`att_5_3_hire') \\ {[246,000]}}} & \multirow{3.4}{*}{\shortstack{`att_5_4' \\ (`att_5_4_hire') \\ {[6,632,775]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm]" _n

	file write table_2 "\multirow{3.4}{*}{\shortstack[l]{\textbf{839}\vphantom{/} \\ \textbf{Industrial Sub-Classes}\vphantom{/} \\ 5-Digit WZ-08}} & \multirow{3.4}{*}{\shortstack{`att_6_99' \\ (`att_6_99_hire') \\ {[839]}}} & \multirow{3.4}{*}{\shortstack{`att_5_1' \\ (`att_5_1_hire') \\ {[13,424]}}} & \multirow{3.4}{*}{\shortstack{`att_6_2' \\ (`att_6_2_hire') \\ {[31,882]}}} & \multirow{3.4}{*}{\shortstack{`att_6_0' \\ (`att_6_0_hire') \\ {[118,299]}}} & \multirow{3.4}{*}{\shortstack{`att_6_3' \\ (`att_6_3_hire') \\ {[335,600]}}} & \multirow{3.4}{*}{\shortstack{`att_6_4' \\ (`att_6_4_hire') \\ {[9,048,615]}}} \\" _n
	file write table_2 "&&&&&& \\" _n
	file write table_2 "&&&&&& \\[0.3cm] \hline" _n
	file write table_2 "\end{tabular}" _n
	file write table_2 "\begin{tablenotes}[para]" _n
	file write table_2 "\footnotesize\textsc{Note. ---} The table displays the self-containment of differently segmented labor markets. Labor markets are pair-wise combinations of industries and regions. The first value in each cell denotes the probability (in percent) that a worker in a certain labor market and year was already employed in the very same labor market in the year before. The second value in each cell (in parentheses) denotes the probability (in percent) that a newly hired worker in a certain labor market and year was already employed in the very same labor market in the year before (i.e., the probability is conditioned on workers who switch firms). The third value in each cell (in brackets) denotes the potential number of labor markets for the specific delineation. Note that the effective number of labor markets is generally lower because certain combinations of industries and region may feature zero workers or hires. The yearly transition probabilities are calculated for workers' who are employed in adjacent years and refer to their main job which is the job (with a length of at least 30 days) that earns the highest daily wage in the respective calendar year. WZ = German Classification of Industries. LAU = Local Administrative Unit. NUTS = Statistical Nomenclature of Territorial Units. Source: BEH, 2012-2023." _n
	file write table_2 "\end{tablenotes}" _n
	file write table_2 "\end{threeparttable}" _n
	file write table_2 "}" _n
	file write table_2 "\end{table}" _n


file close table_2


