



*** 4. REGRESSIONS ***



*** 4.1 LABOR MARKET VARIABLES ***



use "$data\ATT_kldb_1223_V3.dta", replace 

tab year, m
replace year = year + 1
tab year, m

tab inflow_next, m
keep if inflow_next==1


keep year inflow_next kldb10_35_next nuts07_0_next att_35_0

rename kldb10_35_next kldb10_35_imp
rename nuts07_0_next ram

save "$data\LM_22_V1.dta", replace 	




collapse (mean) selfcon=att_35_0, by(kldb10_35_imp ram year)

sum selfcon

tab year, m
keep if year==2022

label variable selfcon "Self-Containment Rate"
		
save "$data\LM_22_V2.dta", replace 	



*** 4.2 PREPARE OCCUPATIONAL VARIABLES ***


use "$orig\Occupational Panel\iab-occpan1222v1.dta", clear


keep kldb10_3plus5 year tnonana_2022 tnoninter_2022 trcog_2022 trman_2022 tnrman_2022

keep if year==2022

rename kldb10_3plus5 kldb10_35_imp 

rename tnonana_2022 ana_nonr
rename tnoninter_2022 int_nonr
rename trcog_2022 cog_rout
rename tnrman_2022 man_nonr
rename trman_2022 man_rout

order man_rout man_nonr cog_rout int_nonr ana_nonr, last


gen sum_test = man_rout + man_nonr + cog_rout + int_nonr + ana_nonr

sum sum_test
hist sum_test

foreach x of varlist man_rout man_nonr cog_rout int_nonr ana_nonr {

	replace `x' = `x' / sum_test	
	
	format %9.3f `x'
}

drop sum_test

gen sum_test = man_rout + man_nonr + cog_rout + int_nonr + ana_nonr

sum sum_test

drop sum_test


label variable kldb10_35_imp "Detailed Occupational Group (KldB10-35)"
label variable year "Year"

label variable man_rout "Share of Manual Routine Tasks (0-1)"
label variable man_nonr "Share of Manual Non-Routine Tasks (0-1)"
label variable cog_rout "Share of Cognitive Routine Tasks (0-1)"
label variable int_nonr "Share of Interatctive Non-Routine Tasks (0-1)"
label variable ana_nonr "Share of Analytical Non-Routine Tasks (0-1)"



save "data/Kldb_22.dta", replace






*** 4.3 PREPARE SPATIAL VARIABLES ***




*population


clear
import excel using "$orig\GENESIS-Regional\12411-01-01-4.xlsx", cellrange(A1:E544)


rename A nuts07_3
rename B nuts07_3_name
rename C pop
drop D E

drop if _n<=6

gen year = 2022

gen nuts07_3_length = length(nuts07_3)

keep if nuts07_3_length==5 | nuts07_3=="02" | nuts07_3=="11"
drop nuts07_3_length

destring pop, force replace
drop if pop==.

replace nuts07_3 = "02000" if nuts07_3=="02"
replace nuts07_3 = "11000" if nuts07_3=="11"

drop nuts07_3_name

destring nuts07_3, force replace

order nuts07_3 year pop

label variable nuts07_3 "District (NUTS07-3)"
label variable year "Year"
label variable pop "Population"


quietly do "$prog\NUTS07-3.do"
label values nuts07_3 nuts07_3



save "data/Nuts_22_V2.dta", replace





*area

clear
import excel using "$orig\GENESIS-Regional\11111-01-01-4.xlsx", cellrange(A1:C543)


rename A nuts07_3
rename B nuts07_3_name
rename C area

drop if _n<=6

gen year = 2022

gen nuts07_3_length = length(nuts07_3)

keep if nuts07_3_length==5 | nuts07_3=="02" | nuts07_3=="11"
drop nuts07_3_length

destring area, force replace
drop if area==.

replace nuts07_3 = "02000" if nuts07_3=="02"
replace nuts07_3 = "11000" if nuts07_3=="11"

drop nuts07_3_name

destring nuts07_3, force replace

order nuts07_3 year area

label variable nuts07_3 "District (NUTS07-3)"
label variable year "Year"
label variable area "Area (in km^2)"


quietly do "$prog\NUTS07-3.do"
label values nuts07_3 nuts07_3



save "data/Nuts_22_V1.dta", replace




*GDP


clear
import excel using "$orig\GENESIS-Regional\82111-01-05-4.xlsx", cellrange(A1:M545)


rename A nuts07_3
rename B nuts07_3_name
rename C gdp
drop D-M

drop if _n<=8

gen year = 2022 // data stem from 2021, but close to 2022

gen nuts07_3_length = length(nuts07_3)

keep if nuts07_3_length==5 | nuts07_3=="02" | nuts07_3=="11"
drop nuts07_3_length

destring gdp, force replace
drop if gdp==.

replace nuts07_3 = "02000" if nuts07_3=="02"
replace nuts07_3 = "11000" if nuts07_3=="11"

drop nuts07_3_name

destring nuts07_3, force replace

order nuts07_3 year gdp

label variable nuts07_3 "District (NUTS07-3)"
label variable year "Year"
label variable gdp "GDP (in 1,000 Euro)"


quietly do "$prog\NUTS07-3.do"
label values nuts07_3 nuts07_3

replace nuts07_3 = 16063 if nuts07_3==16056 // "Eisenach, City" joined "Wartburgkreis" on 1 Jan, 2022

collapse (sum) gdp, by(nuts07_3 year)
label variable gdp "GDP (in 1,000 Euro)"

save "data/Nuts_22_V3.dta", replace


*combine datasets

use "data/Nuts_22_V1.dta", replace

merge 1:1 nuts07_3 year using "data/Nuts_22_V2.dta", keepusing(pop)
drop _merge

merge 1:1 nuts07_3 year using "data/Nuts_22_V3.dta", keepusing(gdp)
drop _merge



merge 1:1 nuts07_3 using "$data\ram.dta", keepusing(ram)
drop _merge

collapse (sum) area pop gdp, by(ram year)

order ram year area pop gdp


replace pop = pop / 1000

label variable area "Area (in km^2)"
label variable pop "Population (in 1,000s)"
label variable gdp "GDP (in 1,000 Euro)"

save "data/RAM_22.dta", replace





*** 4.4 COMBINE DATASETS ***



use "$data\LMC_kldb_35_0_1223.dta", clear	

keep kldb10_35_imp ram year HHI_H_35_0 H_35_0

rename H_35_0 hires

keep if year==2022 // cross section for year 2022


merge 1:1 kldb10_35_imp ram year using "$data\LM_22_V2.dta", keepusing(selfcon)
drop _merge

merge m:1 kldb10_35_imp year using "$data\KldB_22.dta", keepusing(man_rout man_nonr cog_rout int_nonr ana_nonr)
tab year _merge, m
tab kldb10_35_imp _merge if _merge!=2, m
drop _merge


merge m:1 ram year using "$data\RAM_22.dta", keepusing(area pop gdp)
drop _merge


order kldb10_35_imp ram year
sort kldb10_35_imp ram year



*binscatter HHI_H_35_0 log_hires, nquantiles(100)
*binscatter HHI_H_35_0 selfcon, nquantiles(100)


gen log_hires = log(hires)

gen log_area = log(area)
gen log_pop = log(pop)
gen log_gdp = log(gdp)

gen popdens = pop/area
gen log_popdens = log(popdens)

gen gdpcap = gdp/area
gen log_gdpcap = log(gdpcap)


reghdfe HHI_H_35_0 log_hires selfcon man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp, noabsorb vce(cluster kldb10_35_imp ram)  // (4)
keep if e(sample)


reghdfe HHI_H_35_0 log_hires selfcon, noabsorb vce(robust) // (1)

reghdfe HHI_H_35_0 man_rout man_nonr cog_rout ana_nonr, noabsorb vce(robust)
reghdfe HHI_H_35_0 man_rout man_nonr cog_rout ana_nonr, noabsorb vce(cluster kldb10_35_imp) // (2)

reghdfe HHI_H_35_0 log_pop log_area log_gdp, noabsorb vce(robust)
reghdfe HHI_H_35_0 log_pop log_area log_gdp, noabsorb vce(cluster ram) // (3)


reghdfe HHI_H_35_0 man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp, noabsorb vce(robust)


reghdfe HHI_H_35_0 log_hires selfcon man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp, noabsorb vce(robust)
reghdfe HHI_H_35_0 log_hires selfcon man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp, noabsorb vce(cluster kldb10_35_imp ram)  // (4)




*Table 5

local list1 b se


foreach z of numlist 1/4 {

	if `z'==1 { // (1): labor market variables
	
		reghdfe HHI_H_35_0 log_hires selfcon, noabsorb vce(robust) // (1)
		local list2 _cons log_hires selfcon

	}

	else if `z'==2 { // (2): occupational variables
	
		reghdfe HHI_H_35_0 man_rout man_nonr cog_rout ana_nonr, noabsorb vce(cluster kldb10_35_imp) // (2)
		local list2 _cons man_rout man_nonr cog_rout ana_nonr

	}

	else if `z'==3 { // (3): spatial variables

		reghdfe HHI_H_35_0 log_pop log_area log_gdp, noabsorb vce(cluster ram) // (3)
		local list2 _cons log_pop log_area log_gdp

	}
	
	else if `z'==4 { // (4): labor market, occupational, and spatial variables

		reghdfe HHI_H_35_0 log_hires selfcon man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp, noabsorb vce(cluster kldb10_35_imp ram)  // (4)
		local list2 _cons log_hires selfcon man_rout man_nonr cog_rout ana_nonr log_pop log_area log_gdp
		
	}
	



foreach x of local list1 { // coefficients and standard errors (up to 4 digits sufficient, decimals possible, negative values possible, asterisks possible)
		
		foreach y of local list2 {  
			
		
			*second-stage results
			local `x'_`y'_`z' : di %6.4g _`x'[`y']
						 
				 
				 
			*decimals possible: adjust 4-digit format to avoid space before/after number within local
			
			if inrange(``x'_`y'_`z'',10000,.) local `x'_`y'_`z' : di %-6.1e ``x'_`y'_`z''
			else if inrange(``x'_`y'_`z'',1000,9999) local `x'_`y'_`z' : di %5.0f ``x'_`y'_`z''
			else if inrange(``x'_`y'_`z'',100,999.9) local `x'_`y'_`z' : di %5.1f ``x'_`y'_`z''
			else if inrange(``x'_`y'_`z'',10,99.99) local `x'_`y'_`z' : di %3.2f ``x'_`y'_`z'' 
			else if inrange(``x'_`y'_`z'',0.0005,9.999) local `x'_`y'_`z' : di %4.3f ``x'_`y'_`z'' 
			else if inrange(``x'_`y'_`z'',-0.000495,0.000495) local `x'_`y'_`z' : di %4.3f 0 
			else if inrange(``x'_`y'_`z'',-9.999,-0.0005) local `x'_`y'_`z' : di %4.3f ``x'_`y'_`z'' 
			else if inrange(``x'_`y'_`z'',-99.99,-10) local `x'_`y'_`z' : di %3.2f ``x'_`y'_`z''
			else if inrange(``x'_`y'_`z'',-999.9,-100) local `x'_`y'_`z' : di %5.1f ``x'_`y'_`z'' 
			else if inrange(``x'_`y'_`z'',-9999,-1000) local `x'_`y'_`z' : di %5.0f ``x'_`y'_`z''						 
			else if inrange(``x'_`y'_`z'',.,-10000) local `x'_`y'_`z' : di %-6.1e ``x'_`y'_`z''

		
			if `"`x'"'=="b" { // coefficients (negative values possible, asterisks possible)
		
				*negative values or asterisks possible: add "-" and/or "*" and add corresponding fake space on other side
		
				local p_`y'_`z' : di %4.3f  round( 2 * ( 1 - normal( abs( _b[`y'] / _se[`y'] ) ) ) , 0.001 )


			
				*insignificant = no asterisk
				if inrange(``x'_`y'_`z'', 0.0005, .) & inrange(`p_`y'_`z'', 0.100, .) local `x'_`y'_`z' "``x'_`y'_`z''"    // [0.0005,infty[: nothing happens (positive values)
				else if inrange(``x'_`y'_`z'', -0.000495, 0.000495) & inrange(`p_`y'_`z'', 0.100, .) local `x'_`y'_`z' : di %4.3f 0 // [-0.000495,0.000495]: 0.000 (zero)
				else if inrange(``x'_`y'_`z'', ., -0.0005) & inrange(`p_`y'_`z'', 0.100, .) local `x'_`y'_`z' "``x'_`y'_`z''\hphantom{-}"   // ]-infty,-0.0005]: add "\hphantom{-}" to compensate for "-" 

				
				*slightly significant = one asterisk
				else if inrange(``x'_`y'_`z'', 0.0005, .) & inrange(`p_`y'_`z'', 0.050, 0.099) local `x'_`y'_`z' "\hphantom{*}``x'_`y'_`z''*"    // [0.0005,infty[: nothing happens (positive values)
				else if inrange(``x'_`y'_`z'', -0.000495, 0.000495) & inrange(`p_`y'_`z'', 0.050, 0.099) local `x'_`y'_`z'  "\hphantom{*}0.000*"  // [-0.000495,0.000495]: 0.000 (zero)
				else if inrange(``x'_`y'_`z'', ., -0.0005) & inrange(`p_`y'_`z'', 0.050, 0.099) local `x'_`y'_`z' "\hphantom{*}``x'_`y'_`z''*\hphantom{-}"   // ]-infty,-0.0005]: add "\hphantom{-}" to compensate for "-" 

				
				*significant = two asterisks
				else if inrange(``x'_`y'_`z'', 0.0005, .) & inrange(`p_`y'_`z'', 0.010, 0.049) local `x'_`y'_`z' "\hphantom{**}``x'_`y'_`z''**"    // [0.0005,infty[: nothing happens (positive values)
				else if inrange(``x'_`y'_`z'', -0.000495, 0.000495) & inrange(`p_`y'_`z'', 0.010, 0.049) local `x'_`y'_`z'  "\hphantom{**}0.000**"  // [-0.000495,0.000495]: 0.000 (zero)
				else if inrange(``x'_`y'_`z'', ., -0.0005) & inrange(`p_`y'_`z'', 0.010, 0.049) local `x'_`y'_`z' "\hphantom{**}``x'_`y'_`z''**\hphantom{-}"   // ]-infty,-0.0005]: add "\hphantom{-}" to compensate for "-" 

				*highly significant = three asterisks
				else if inrange(``x'_`y'_`z'', 0.0005, .) & inrange(`p_`y'_`z'', 0.000, 0.009) local `x'_`y'_`z' "\hphantom{***}``x'_`y'_`z''***"    // [0.0005,infty[: nothing happens (positive values)
				else if inrange(``x'_`y'_`z'', -0.000495, 0.000495) & inrange(`p_`y'_`z'', 0.000, 0.009) local `x'_`y'_`z'  "\hphantom{***}0.000***"  // [-0.000495,0.000495]: 0.000 (zero)
				else if inrange(``x'_`y'_`z'', ., -0.0005) & inrange(`p_`y'_`z'', 0.000, 0.009) local `x'_`y'_`z' "\hphantom{***}``x'_`y'_`z''***\hphantom{-}"   // ]-infty,-0.0005]: add "\hphantom{-}" to compensate for "-" 

				
			}
			
			else if `"`x'"'=="se" { // standard errors (negative values impossible, asterisks impossible)
		
			}						
			


			
			di `"`x'_`y'_`z'"'
			di "``x'_`y'_`z''"
			
			di `"p_`y'_`z'"'
			di "`p_`y'_`z''"

				
		}
	}
	
	*number of observations (up to 8 digits sufficient, decimals impossible, negative values impossible, asterisks impossible)

	local N_`z' : di %-12.0gc e(N)
	di `"N_`z'"'
	di "`N_`z''"
	
	
	*adjusted R2 (up to 4 digits sufficient, decimals possible, negative values unlikely, asterisks impossible)

	local R2_`z' : di %4.3f e(r2)
	di `"R2_`z'"'
	di "`R2_`z''"
	
	
	
	
}













file open table_5 using "$file\Table 5.tex", write replace

	file write table_5 "\begin{table}[!ht]" _n
	file write table_5 "\centering" _n
	file write table_5 "%\resizebox{\textwidth}{!}{" _n
	file write table_5 "\scalebox{0.90}{" _n
	file write table_5 "\begin{threeparttable}" _n
	file write table_5 "\caption{Predictors of Labor Market Concentration}" _n
	file write table_5 "\label{tab:5}" _n
	file write table_5 "\begin{tabular}{L{6.2cm}C{2.2cm}C{2.2cm}C{2.2cm}C{2.2cm}} \hline" _n
	file write table_5 "&&&& \\[-0.3cm]" _n
	file write table_5 "\multirow{2.4}{*}{} & \multirow{2.4}{*}{\shortstack{(1) \\ HHI }} & \multirow{2.4}{*}{\shortstack{(2) \\ HHI }} & \multirow{2.4}{*}{\shortstack{(3) \\ HHI }}  & \multirow{2.4}{*}{\shortstack{(4) \\ HHI }} \\" _n
	file write table_5 "&&&& \\[0.3cm] \hline" _n
	file write table_5 "&&&& \\[-0.3cm]" _n
	file write table_5 "\multirow{2.4}{*}{Intercept} &  \multirow{2.4}{*}{\shortstack{`b__cons_1'  \\ (`se__cons_1')}}  & \multirow{2.4}{*}{\shortstack{`b__cons_2'  \\ (`se__cons_2')}}  & \multirow{2.4}{*}{\shortstack{`b__cons_3'  \\ (`se__cons_3')}}   & \multirow{2.4}{*}{\shortstack{`b__cons_4'  \\ (`se__cons_4')}}  \\" _n
	file write table_5 "&&&& \\[0.2cm]" _n
	file write table_5 "\multicolumn{4}{l}{\textbf{Labor Market Variables:}} \\" _n
	file write table_5 "\multirow{2.4}{*}{Log Hires} &  \multirow{2.4}{*}{\shortstack{`b_log_hires_1'  \\ (`se_log_hires_1')}}  & & & \multirow{2.4}{*}{\shortstack{`b_log_hires_4'  \\ (`se_log_hires_4')}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Self-Containment Rate} &  \multirow{2.4}{*}{\shortstack{`b_selfcon_1'  \\ (`se_selfcon_1')}}  & & & \multirow{2.4}{*}{\shortstack{`b_selfcon_4'  \\ (`se_selfcon_4')}}    \\" _n
	file write table_5 "&&&& \\[0.4cm]" _n	
	file write table_5 "\multicolumn{4}{l}{\textbf{Occupational Variables:}} \\" _n
	file write table_5 "\multirow{2.4}{*}{Share Manual Routine Tasks} &  & \multirow{2.4}{*}{\shortstack{`b_man_rout_2'  \\ (`se_man_rout_2')}}  & & \multirow{2.4}{*}{\shortstack{`b_man_rout_4'  \\ (`se_man_rout_4')}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Share Manual Non-Routine Tasks} &  & \multirow{2.4}{*}{\shortstack{`b_man_nonr_2'  \\ (`se_man_nonr_2')}}  & & \multirow{2.4}{*}{\shortstack{`b_man_nonr_4'  \\ (`se_man_nonr_4')}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Share Cognitive Routine Tasks} &  & \multirow{2.4}{*}{\shortstack{`b_cog_rout_2'  \\ (`se_cog_rout_2')}}  & & \multirow{2.4}{*}{\shortstack{`b_cog_rout_4'  \\ (`se_cog_rout_4')}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Share Interactive Non-Routine Tasks} &  & \multirow{2.4}{*}{\shortstack{Reference \\ Group}}  &  \multirow{2.4}{*}{} & \multirow{2.4}{*}{\shortstack{Reference \\ Group}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Share Analytical Non-Routine Tasks} &  & \multirow{2.4}{*}{\shortstack{`b_ana_nonr_2'  \\ (`se_ana_nonr_2')}}  & & \multirow{2.4}{*}{\shortstack{`b_ana_nonr_4'  \\ (`se_ana_nonr_4')}}    \\" _n
	file write table_5 "&&&& \\[0.4cm]" _n
	file write table_5 "\multicolumn{4}{l}{\textbf{Spatial Variables:}} \\" _n
	file write table_5 "\multirow{2.4}{*}{Log Population (in 1,000s)} &  &  & \multirow{2.4}{*}{\shortstack{`b_log_pop_3'  \\ (`se_log_pop_3')}} & \multirow{2.4}{*}{\shortstack{`b_log_pop_4'  \\ (`se_log_pop_4')}}    \\" _n
	file write table_5 "&&&& \\" _n
	file write table_5 "\multirow{2.4}{*}{Log Area (in km$^{2}$)} &  &  & \multirow{2.4}{*}{\shortstack{`b_log_area_3'  \\ (`se_log_area_3')}} & \multirow{2.4}{*}{\shortstack{`b_log_area_4'  \\ (`se_log_area_4')}}    \\" _n
	file write table_5 "&&&& \\" _n	
	file write table_5 "\multirow{2.4}{*}{Log GDP (in 1,000 Euro)} &  &  & \multirow{2.4}{*}{\shortstack{`b_log_gdp_3'  \\ (`se_log_gdp_3')}} & \multirow{2.4}{*}{\shortstack{`b_log_gdp_4'  \\ (`se_log_gdp_4')}}    \\" _n
	file write table_5 "&&&& \\[0.4cm] \hline" _n
	file write table_5 "&&&& \\[-0.2cm]" _n
	file write table_5 "Labor Market Definition & \multicolumn{4}{c}{Detailed 3-Digit Occupation $\times$ Commuting Zone}  \\[0.2cm] " _n
	file write table_5 "\multirow{2.4}{*}{Standard Error Clustering}  & \multirow{2.4}{*}{None} & \multirow{2.4}{*}{Occupation} &  \multirow{2.4}{*}{CZ} & \multirow{2.4}{*}{\shortstack{Occupation \\ CZ}} \\[0.2cm] " _n
	file write table_5 "&&&& \\" _n		
	file write table_5 "Number of Observations &  `N_1'       & `N_2'       & `N_3'  & `N_4'   \\[0.2cm]" _n
	file write table_5 "R$^{2}$ &  `R2_1'       & `R2_2'       & `R2_3'   & `R2_4'            \\[0.2cm]  \hline" _n
	file write table_5 "\end{tabular}" _n
	file write table_5 "\begin{tablenotes}[para]" _n
	file write table_5 "\footnotesize\textsc{Note. ---} The table displays cross-sectional OLS regressions of our baseline HHI values on labor market, occupational, and spatial variables for the year 2022. Labor market concentration refers to HHI values (based on hiring shares) for pair-wise combinations of 3-digit KldB-2010 occupations (along with their requirement level) and commuting zones from \citet{KosfeldWerner2012}. Unlike all other variables, the data on GDP refer to the year 2021. Robust standard errors in parentheses, Column 4 applies two-way clustering. CZ = Commuting Zone. HHI = Herfindahl-Hirschman Index. * = p$<$0.10. ** = p$<$0.05. *** = p$<$0.01. Sources: BEH $\plus$ Occupational Panel $\plus$ Destatis, 2022." _n
	file write table_5 "\end{tablenotes}" _n
	file write table_5 "\end{threeparttable}" _n
	file write table_5 "}" _n
	file write table_5 "\end{table}" _n

file close table_5